#### Accuracy of Smartphone and External Handheld GPS Receivers ####
#### October 2023 ####
#### LWM ewsn Fixed Point Survey Data ####
############################################

setwd("~/Desktop/PC_Folders/LHB/Manuscripts/GPS_Calibration/GPSCalibration_SupplementalData/GPS_Data_Processing/GPX_Data")
list.files()
list.files(pattern=".gpx")

library(XML)
library(ggplot2)
library(scales)
#library(ggforce)
library(sp)

options(digits=9)
options(scipen=999)

####
#from Trimble data using Wilton-Jones transformation
x= -2.4748789803808
y= 53.450914719012

#Deduce Lat difference for 2m radius on y axis
Y=data.frame(x,y+0.000009)
Y <-as.matrix(Y)
1000*(spDistsN1(pts=Y,pt=c(x,y),longlat=TRUE))
ymin=y-(2*0.0000090);ymin#
ymax=y+(2*0.0000090);ymax#

#Deduce Lon difference for 2m radius on x axis
X=data.frame(x+0.0000151,y)
X <-as.matrix(X)
1000*(spDistsN1(pts=X,pt=c(x,y),longlat=TRUE))
xmin=x-(2*0.0000151);xmin#
xmax=x+(2*0.0000151);xmax#


#Data processing for Fixed Point Survey
#Import GPX tracks
list.files(pattern="2023-10-15")
#Import GPX
BES_F1.gpx <- htmlTreeParse(file = "2023-10-15 13_37_01 ewsn BES.gpx", useInternalNodes = TRUE)
#Extract lon/lat coordinates
BES_F1.coords <- xpathSApply(doc = BES_F1.gpx, path = "//trkpt", fun = xmlAttrs)
#?xpathSApply
#convert into dataframe
BES_F.1.df <- data.frame(Repeat=1, Date=151023,Receiver="BES",
  lon = as.numeric(BES_F1.coords["lon", ]),
  lat = as.numeric(BES_F1.coords["lat",]))
ggplot(data=BES_F.1.df, aes(x=lon, y=lat))+geom_point() + 
  scale_x_continuous(limits = c(-2.474950,-2.474850))+
  scale_y_continuous(limits = c(53.450850,53.450950))+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.375)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.03,colour="red")
####
BELC_F1.gpx <- htmlTreeParse(file = "2023-10-15 13_37_04 ewsn BELC.gpx", useInternalNodes = TRUE)
BELC_F1.coords <- xpathSApply(doc = BELC_F1.gpx, path = "//trkpt", fun = xmlAttrs)
BELC_F.1.df <- data.frame(Repeat=1, Date=151023,
Receiver="BELC",
      lon = as.numeric(BELC_F1.coords["lon", ]),
      lat = as.numeric(BELC_F1.coords["lat",])
    )
ggplot(data=BELC_F.1.df, aes(x=lon, y=lat))+geom_point()  + 
  scale_x_continuous(limits = c(-2.474950,-2.474850))+
  scale_y_continuous(limits = c(53.450850,53.450950))+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.375)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.03,colour="red")
####
iP12_F.1.gpx <- htmlTreeParse(file = "2023-10-15 13_37_06 ewsn iPhone 12.gpx", useInternalNodes = TRUE)
iP12_F.1.coords <- xpathSApply(doc = iP12_F.1.gpx, path = "//trkpt", fun = xmlAttrs)
iP12_F.1.df <- data.frame(Repeat=1, Date=151023,
Receiver="iP12",
      lon = as.numeric(iP12_F.1.coords["lon", ]),
      lat = as.numeric(iP12_F.1.coords["lat",])
    )
ggplot(data=iP12_F.1.df, aes(x=lon, y=lat))+geom_point() + 
  scale_x_continuous(limits = c(-2.474950,-2.474850))+
  scale_y_continuous(limits = c(53.450850,53.450950))+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.375)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.03,colour="red")
####
iP6_F.1.gpx <- htmlTreeParse(file = "2023-10-15 13_37_03 ewsn iPhone 6.gpx", useInternalNodes = TRUE)
iP6_F.1.coords <- xpathSApply(doc = iP6_F.1.gpx, path = "//trkpt", fun = xmlAttrs)
iP6_F.1.df <- data.frame(Repeat=1, Date=151023,
Receiver="iP6",
      lon = as.numeric(iP6_F.1.coords["lon", ]),
      lat = as.numeric(iP6_F.1.coords["lat",])
    )
ggplot(data=iP6_F.1.df, aes(x=lon, y=lat))+geom_point() + 
  scale_x_continuous(limits = c(-2.474950,-2.474850))+
  scale_y_continuous(limits = c(53.450850,53.450950))+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.375)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.03,colour="red")
########
list.files(pattern="2023-10-23")

BES_F2.gpx <- htmlTreeParse(file = "2023-10-23 15_05_35 ewsn BES.gpx", useInternalNodes = TRUE)
BES_F2.coords <- xpathSApply(doc = BES_F2.gpx, path = "//trkpt", fun = xmlAttrs)
BES_F.2.df <- data.frame(Repeat=2, Date=231023,Receiver="BES",
                      lon = as.numeric(BES_F2.coords["lon", ]),
                      lat = as.numeric(BES_F2.coords["lat",]))
ggplot(data=BES_F.2.df, aes(x=lon, y=lat))+geom_point(cex=0.25) + 
  scale_x_continuous(limits = c(-2.474950,-2.474850))+
  scale_y_continuous(limits = c(53.450850,53.450950))+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.375)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.03,colour="red")
####
BELC_F2.gpx <- htmlTreeParse(file = "2023-10-23 15_05_30 ewsn BELC.gpx", useInternalNodes = TRUE)
BELC_F2.coords <- xpathSApply(doc = BELC_F2.gpx, path = "//trkpt", fun = xmlAttrs)
BELC_F.2.df <- data.frame(Repeat=2, Date=231023,
                       Receiver="BELC",
                       lon = as.numeric(BELC_F2.coords["lon", ]),
                       lat = as.numeric(BELC_F2.coords["lat",]))
ggplot(data=BELC_F.2.df, aes(x=lon, y=lat))+geom_point() + 
  scale_x_continuous(limits = c(-2.474950,-2.474850))+
  scale_y_continuous(limits = c(53.450850,53.450950))+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.375)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.03,colour="red")

####
iP12_F.2.gpx <- htmlTreeParse(file = "2023-10-23 15_05_31 ewsn iPhone 12.gpx", useInternalNodes = TRUE)
iP12_F.2.coords <- xpathSApply(doc = iP12_F.2.gpx, path = "//trkpt", fun = xmlAttrs)
iP12_F.2.df <- data.frame(Repeat=2, Date=231023,
                        Receiver="iP12",
                        lon = as.numeric(iP12_F.2.coords["lon", ]),
                        lat = as.numeric(iP12_F.2.coords["lat",]))
ggplot(data=iP12_F.2.df, aes(x=lon, y=lat))+geom_point() + 
  scale_x_continuous(limits = c(-2.474950,-2.474850))+
  scale_y_continuous(limits = c(53.450850,53.450950))+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.375)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.03,colour="red")

####
iP6_F.2.gpx <- htmlTreeParse(file = "2023-10-23 15_05_27 ewsn iPhone 6.gpx", useInternalNodes = TRUE)
iP6_F.2.coords <- xpathSApply(doc = iP6_F.2.gpx, path = "//trkpt", fun = xmlAttrs)
iP6_F.2.df <- data.frame(Repeat=2, Date=231023,
                       Receiver="iP6",
                       lon = as.numeric(iP6_F.2.coords["lon", ]),
                       lat = as.numeric(iP6_F.2.coords["lat",]))
ggplot(data=iP6_F.2.df, aes(x=lon, y=lat))+geom_point() + 
  scale_x_continuous(limits = c(-2.474950,-2.474850))+
  scale_y_continuous(limits = c(53.450850,53.450950))+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.375)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.03,colour="red")
########
list.files(pattern="2023-10-24")

BES_F3.gpx <- htmlTreeParse(file = "2023-10-24 16_16_19 ewsn BES.gpx", useInternalNodes = TRUE)
BES_F3.coords <- xpathSApply(doc = BES_F3.gpx, path = "//trkpt", fun = xmlAttrs)
BES_F.3.df <- data.frame(Repeat=3, Date=241023,
      Receiver="BES",
      lon = as.numeric(BES_F3.coords["lon", ]),
      lat = as.numeric(BES_F3.coords["lat",]))
ggplot(data=BES_F.3.df, aes(x=lon, y=lat))+geom_point(cex=0.25)  + 
  scale_x_continuous(limits = c(-2.474950,-2.474850))+
  scale_y_continuous(limits = c(53.450850,53.450950))+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.375)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.03,colour="red")
####

BELC_F3.gpx <- htmlTreeParse(file = "2023-10-24 16_16_15 ewsn BELC.gpx", useInternalNodes = TRUE)
BELC_F3.coords <- xpathSApply(doc = BELC_F3.gpx, path = "//trkpt", fun = xmlAttrs)
BELC_F.3.df <- data.frame(Repeat=3, Date=241023,
Receiver="BELC",
      lon = as.numeric(BELC_F3.coords["lon", ]),
      lat = as.numeric(BELC_F3.coords["lat",]))
ggplot(data=BELC_F.3.df, aes(x=lon, y=lat))+geom_point()  + 
  scale_x_continuous(limits = c(-2.474950,-2.474850))+
  scale_y_continuous(limits = c(53.450850,53.450950))+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.375)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.03,colour="red")
####

iP12_F.3.gpx <- htmlTreeParse(file = "2023-10-24 16_16_17 ewsn iPhone 12.gpx", useInternalNodes = TRUE)
iP12_F.3.coords <- xpathSApply(doc = iP12_F.3.gpx, path = "//trkpt", fun = xmlAttrs)
iP12_F.3.df <- data.frame(Repeat=3, Date=241023,
Receiver="iP12",
      lon = as.numeric(iP12_F.3.coords["lon", ]),
      lat = as.numeric(iP12_F.3.coords["lat",]))
ggplot(data=iP12_F.3.df, aes(x=lon, y=lat))+geom_point()+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.375)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.03,colour="red")
####

iP6_F.3.gpx <- htmlTreeParse(file = "2023-10-24 16_16_13 ewsn iPhone 6.gpx", useInternalNodes = TRUE)
iP6_F.3.coords <- xpathSApply(doc = iP6_F.3.gpx, path = "//trkpt", fun = xmlAttrs)
iP6_F.3.df <- data.frame(Repeat=3, Date=241023,
Receiver="iP6",
      lon = as.numeric(iP6_F.3.coords["lon", ]),
      lat = as.numeric(iP6_F.3.coords["lat",]))
ggplot(data=iP6_F.3.df, aes(x=lon, y=lat))+geom_point()+ 
  scale_x_continuous(limits = c(-2.475000,-2.47470400))+
  scale_y_continuous(limits = c(53.450800,53.450990))+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.375)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.03,colour="red")
####

list.files(pattern="2023-10-25")

BES_F4.gpx <- htmlTreeParse(file = "2023-10-25 14_44_06 ewsn BES.gpx", useInternalNodes = TRUE)
BES_F4.coords <- xpathSApply(doc = BES_F4.gpx, path = "//trkpt", fun = xmlAttrs)
BES_F.4.df <- data.frame(Repeat=4, Date=251023,
                      Receiver="BES",
                      lon = as.numeric(BES_F4.coords["lon", ]),
                      lat = as.numeric(BES_F4.coords["lat",]))
ggplot(data=BES_F.4.df, aes(x=lon, y=lat))+geom_point()  + 
  scale_x_continuous(limits = c(-2.474950,-2.474850))+
  scale_y_continuous(limits = c(53.450850,53.450950))+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.375)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.03,colour="red")
####

BELC_F4.gpx <- htmlTreeParse(file = "2023-10-25 14_44_18 ewsn BELC.gpx", useInternalNodes = TRUE)
BELC_F4.coords <- xpathSApply(doc = BELC_F4.gpx, path = "//trkpt", fun = xmlAttrs)
BELC_F.4.df <- data.frame(Repeat=4, Date=251023,
                       Receiver="BELC",
                       lon = as.numeric(BELC_F4.coords["lon", ]),
                       lat = as.numeric(BELC_F4.coords["lat",]))
ggplot(data=BELC_F.4.df, aes(x=lon, y=lat))+geom_point()  + 
  scale_x_continuous(limits = c(-2.474950,-2.474850))+
  scale_y_continuous(limits = c(53.450850,53.450950))+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.375)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.03,colour="red")
####

iP12_F.4.gpx <- htmlTreeParse(file = "2023-10-25 14_44_17 ewsn iPhone 12.gpx", useInternalNodes = TRUE)
iP12_F.4.coords <- xpathSApply(doc = iP12_F.4.gpx, path = "//trkpt", fun = xmlAttrs)
iP12_F.4.df <- data.frame(Repeat=4, Date=251023,
                        Receiver="iP12",
                        lon = as.numeric(iP12_F.4.coords["lon", ]),
                        lat = as.numeric(iP12_F.4.coords["lat",]))
ggplot(data=iP12_F.4.df, aes(x=lon, y=lat))+geom_point()  + 
  scale_x_continuous(limits = c(-2.474950,-2.474850))+
  scale_y_continuous(limits = c(53.450850,53.450950))+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.375)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.03,colour="red")
####

iP6_F.4.gpx <- htmlTreeParse(file = "2023-10-25 14_44_19 ewsn iPhone 6.gpx", useInternalNodes = TRUE)
iP6_F.4.coords <- xpathSApply(doc = iP6_F.4.gpx, path = "//trkpt", fun = xmlAttrs)
iP6_F.4.df <- data.frame(Repeat=4, Date=251023,
                       Receiver="iP6",
                       lon = as.numeric(iP6_F.4.coords["lon", ]),
                       lat = as.numeric(iP6_F.4.coords["lat",]))
ggplot(data=iP6_F.4.df, aes(x=lon, y=lat))+geom_point()  + 
  scale_x_continuous(limits = c(-2.474950,-2.474850))+
  scale_y_continuous(limits = c(53.450850,53.450950))+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.375)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.03,colour="red")
####

list.files(pattern="2023-10-26")

BES_F5.gpx <- htmlTreeParse(file = "2023-10-26 16_34_27 ewsn BES.gpx", useInternalNodes = TRUE)
BES_F5.coords <- xpathSApply(doc = BES_F5.gpx, path = "//trkpt", fun = xmlAttrs)
BES_F.5.df <- data.frame(Repeat=5, Date=261023,
                      Receiver="BES",
                      lon = as.numeric(BES_F5.coords["lon", ]),
                      lat = as.numeric(BES_F5.coords["lat",]))
ggplot(data=BES_F.5.df, aes(x=lon, y=lat))+geom_point()  + 
  scale_x_continuous(limits = c(-2.474950,-2.474850))+
  scale_y_continuous(limits = c(53.450850,53.450950))+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.375)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.03,colour="red")
####

BELC_F5.gpx <- htmlTreeParse(file = "2023-10-26 16_34_30 ewsn BELC .gpx", useInternalNodes = TRUE)
BELC_F5.coords <- xpathSApply(doc = BELC_F5.gpx, path = "//trkpt", fun = xmlAttrs)
BELC_F.5.df <- data.frame(Repeat=5, Date=261023,
                       Receiver="BELC",
                       lon = as.numeric(BELC_F5.coords["lon", ]),
                       lat = as.numeric(BELC_F5.coords["lat",]))
ggplot(data=BELC_F.5.df, aes(x=lon, y=lat))+geom_point()+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.375)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.03,colour="red")
####

iP12_F.5.gpx <- htmlTreeParse(file = "2023-10-26 16_34_30 ewsn iPhone 12.gpx", useInternalNodes = TRUE)
iP12_F.5.coords <- xpathSApply(doc = iP12_F.5.gpx, path = "//trkpt", fun = xmlAttrs)
iP12_F.5.df <- data.frame(Repeat=5, Date=261023,
                        Receiver="iP12",
                        lon = as.numeric(iP12_F.5.coords["lon", ]),
                        lat = as.numeric(iP12_F.5.coords["lat",]))
ggplot(data=iP12_F.5.df, aes(x=lon, y=lat))+geom_point()+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.375)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.03,colour="red")
####

iP6_F.5.gpx <- htmlTreeParse(file = "2023-10-26 16_34_31 ewsn iPhone 6.gpx", useInternalNodes = TRUE)
iP6_F.5.coords <- xpathSApply(doc = iP6_F.5.gpx, path = "//trkpt", fun = xmlAttrs)
iP6_F.5.df <- data.frame(Repeat=5, Date=310523,
                       Receiver="iP6",
                       lon = as.numeric(iP6_F.5.coords["lon", ]),
                       lat = as.numeric(iP6_F.5.coords["lat",]))
ggplot(data=iP6_F.5.df, aes(x=lon, y=lat))+geom_point()+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.375)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.03,colour="red")

#########################################################

##Merge data
#options(digits=9)
#options(scipen=999)
#Merge point measurement data
EWSN_F <-rbind(BES_F.1.df,BELC_F.1.df,iP12_F.1.df,iP6_F.1.df,
            BES_F.2.df,BELC_F.2.df,iP12_F.2.df,iP6_F.2.df,
            BES_F.3.df,BELC_F.3.df,iP12_F.3.df,iP6_F.3.df,
            BES_F.4.df,BELC_F.4.df,iP12_F.4.df,iP6_F.4.df,
            BES_F.5.df,BELC_F.5.df,iP12_F.5.df,iP6_F.5.df)
names(EWSN_F)
nrow(EWSN_F)

ggplot(data=EWSN_F, aes(x=lon, y=lat))+ geom_jitter(width=0.000003,height=0.000003,size=0.3,aes(colour=Receiver))+
  theme_bw()

##Distance Calculation(m)
#library(sp)

Measurements <- matrix(c(EWSN_F$lon,EWSN_F$lat),ncol=2)
head(Measurements)
nrow(Measurements)
#Calc Distance from base station (m) from lon-lat data (WSG84)
EWSN_F.dist <-1000*(spDistsN1(pts=Measurements,
                           pt=c(x,y), 
                           longlat=TRUE))
range(EWSN_F.dist)
class(EWSN_F.dist)

EWSN_F$Dist <-EWSN_F.dist

#Write .csv
setwd("~/Desktop/PC_Folders/LHB/Manuscripts/GPS_Calibration/GPS_Data_Processing")
write.csv(EWSN_F,file="Fixed_BaseStation_Survey.csv")
#######################################

