#### Accuracy of Smartphone and External Handheld GPS Receivers #### 
#### October 2023 ####
#### LWM ew and sn Transect Survey Data ####
############################################

setwd("~/Desktop/PC_Folders/LHB/Manuscripts/GPS_Calibration/GPSCalibration_SupplementalData/GPS_Data_Processing/GPX_Data")
list.files()
list.files(pattern=".gpx")

library(XML)
library(ggplot2)
library(scales)
#library(ggforce)
#?xml
options(digits=9)
options(scipen=999)

#from Trimble data using Wilton-Jones transformation
x=-2.4748789803808
y=53.450914719012

#Deduce Lat difference for 1m radius on y axis
Y=data.frame(x,y+0.000009)
Y <-as.matrix(Y)
1000*(spDistsN1(pts=Y,pt=c(x,y),longlat=TRUE))
ymin=(y-0.0000090);ymin#
ymax=(y+0.0000090);ymax#

#Deduce Lon difference for 1m radius on x axis
X=data.frame(x+0.0000151,y)
X <-as.matrix(X)
1000*(spDistsN1(pts=X,pt=c(x,y),longlat=TRUE))
xmin=x-0.0000151;xmin#
xmax=x+0.0000151;xmax#

####
#ew coordinates from Trimble data data using Wilton-Jones transformation
ew.x=-2.4747094849943
ew.y=53.450964541335
#Deduce Lat difference for 1m radius on y axis
ew.Y=data.frame(ew.x,ew.y+0.0000089851)
ew.Y <-as.matrix(ew.Y)
1000*(spDistsN1(pts=ew.Y,pt=c(ew.x,ew.y),longlat=TRUE))
ew.ymin=(ew.y-0.0000090);ew.ymin#53.4509286
ew.ymax=(ew.y+0.0000090);ew.ymax#53.4509466

#Deduce Lon difference for 1m radius on x axis
ew.X=data.frame(ew.x+0.0000150523,ew.y)
ew.X <-as.matrix(ew.X)
1000*(spDistsN1(pts=ew.X,pt=c(ew.x,ew.y),longlat=TRUE))
ew.xmin=(ew.x-0.0000151);ew.xmin#-2.47482091
ew.xmax=(ew.x+0.0000151);ew.xmax#-2.47479071
#######################################################

#Data processing for East-West transect
#Import GPX tracks
list.files(pattern="2024-01-14")
#Import GPX
BES1ew.gpx <- htmlTreeParse(file = "2024-01-14 15_52_01 BES ew .gpx", useInternalNodes = TRUE)
#Extract lon/lat coordinates
BES1ew.coords <- xpathSApply(doc = BES1ew.gpx, path = "//trkpt", fun = xmlAttrs)
#convert into dataframe
BES.ew.1.df <- data.frame(Repeat=1, Date=151023,Receiver="BES", Transect="ew",
                       lon = as.numeric(BES1ew.coords["lon", ]),
                       lat = as.numeric(BES1ew.coords["lat",]))
ggplot(data=BES.ew.1.df, aes(x=lon, y=lat))+geom_point() + 
  #scale_x_continuous(limits = c(-2.474950,-2.474850))+
  #scale_y_continuous(limits = c(53.450850,53.450950))+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.75)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.55,colour="red")

####
BELC1ew.gpx <- htmlTreeParse(file = "2024-01-14 15_51_58 BELC ew .gpx", useInternalNodes = TRUE)
BELC1ew.coords <- xpathSApply(doc = BELC1ew.gpx, path = "//trkpt", fun = xmlAttrs)
BELC.ew.1.df <- data.frame(Repeat=1, Date=151023, Transect="ew",
                        Receiver="BELC",
                        lon = as.numeric(BELC1ew.coords["lon", ]),
                        lat = as.numeric(BELC1ew.coords["lat",])
)
nrow(BELC.ew.1.df)
names(BELC.ew.1.df)
range(BELC.ew.1.df$lon)
ggplot(data=BELC.ew.1.df, aes(x=lon, y=lat))+geom_point()  + 
  #scale_x_continuous(limits = c(-2.474950,-2.474850))+
  #scale_y_continuous(limits = c(53.450850,53.450950))+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.75)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.55,colour="red")

####
iP12.1ew.gpx <- htmlTreeParse(file = "2024-01-14 15_52_00 iP12 ew .gpx", useInternalNodes = TRUE)
iP12.1ew.coords <- xpathSApply(doc = iP12.1ew.gpx, path = "//trkpt", fun = xmlAttrs)
iP12.ew.1.df <- data.frame(Repeat=1, Date=151023, Transect="ew",
                        Receiver="iP12",
                        lon = as.numeric(iP12.1ew.coords["lon", ]),
                        lat = as.numeric(iP12.1ew.coords["lat",])
)
nrow(iP12.ew.1.df)
ggplot(data=iP12.ew.1.df, aes(x=lon, y=lat))+geom_point() + 
  #scale_x_continuous(limits = c(-2.474950,-2.474850))+
  #scale_y_continuous(limits = c(53.450850,53.450950))+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.75)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.55,colour="red")

####
iP6.1ew.gpx <- htmlTreeParse(file = "2024-01-14 15_51_57 iP6 ew .gpx", useInternalNodes = TRUE)
iP6.1ew.coords <- xpathSApply(doc = iP6.1ew.gpx, path = "//trkpt", fun = xmlAttrs)
iP6.ew.1.df <- data.frame(Repeat=1, Date=151023, Transect ="ew",
                       Receiver="iP6",
                       lon = as.numeric(iP6.1ew.coords["lon", ]),
                       lat = as.numeric(iP6.1ew.coords["lat",])
)
ggplot(data=iP6.ew.1.df, aes(x=lon, y=lat))+geom_point() + 
  #scale_x_continuous(limits = c(-2.474950,-2.474850))+
  #scale_y_continuous(limits = c(53.450850,53.450950))+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.75)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.55,colour="red")

########
list.files(pattern="2024-01-15")

BES2ew.gpx <- htmlTreeParse(file = "2024-01-15 14_28_41 BES ew.gpx", useInternalNodes = TRUE)
BES2ew.coords <- xpathSApply(doc = BES2ew.gpx, path = "//trkpt", fun = xmlAttrs)
BES.ew.2.df <- data.frame(Repeat=2, Date=251023,Receiver="BES", Transect="ew",
                       lon = as.numeric(BES2ew.coords["lon", ]),
                       lat = as.numeric(BES2ew.coords["lat",]))
nrow(BES.ew.2.df)
ggplot(data=BES.ew.2.df, aes(x=lon, y=lat))+geom_point(cex=0.25) + 
  #scale_x_continuous(limits = c(-2.474950,-2.474850))+
  #scale_y_continuous(limits = c(53.450850,53.450950))+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.75)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.55,colour="red")

####
BELC2ew.gpx <- htmlTreeParse(file = "2024-01-15 14_28_39 BELC ew.gpx", useInternalNodes = TRUE)
BELC2ew.coords <- xpathSApply(doc = BELC2ew.gpx, path = "//trkpt", fun = xmlAttrs)
BELC.ew.2.df <- data.frame(Repeat=2, Date=221023, Transect="ew",
                        Receiver="BELC",
                        lon = as.numeric(BELC2ew.coords["lon", ]),
                        lat = as.numeric(BELC2ew.coords["lat",]))
nrow(BELC.ew.2.df)
ggplot(data=BELC.ew.2.df, aes(x=lon, y=lat))+geom_point() + 
  #scale_x_continuous(limits = c(-2.474950,-2.474850))+
  #scale_y_continuous(limits = c(53.450850,53.450950))+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.75)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.55,colour="red")

####
iP12.2ew.gpx <- htmlTreeParse(file = "2024-01-15 14_28_41 iP12 ew.gpx", useInternalNodes = TRUE)
iP12.2ew.coords <- xpathSApply(doc = iP12.2ew.gpx, path = "//trkpt", fun = xmlAttrs)
iP12.ew.2.df <- data.frame(Repeat=2, Date=231023, Transect="ew",
                        Receiver="iP12",
                        lon = as.numeric(iP12.2ew.coords["lon", ]),
                        lat = as.numeric(iP12.2ew.coords["lat",]))
nrow(iP12.ew.2.df)
ggplot(data=iP12.ew.2.df, aes(x=lon, y=lat))+geom_point() + 
  #scale_x_continuous(limits = c(-2.474950,-2.474850))+
  #scale_y_continuous(limits = c(53.450850,53.450950))+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.75)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.55,colour="red")

####
iP6.2ew.gpx <- htmlTreeParse(file = "2024-01-15 14_28_39 iP6 ew .gpx", useInternalNodes = TRUE)
iP6.2ew.coords <- xpathSApply(doc = iP6.2ew.gpx, path = "//trkpt", fun = xmlAttrs)
iP6.ew.2.df <- data.frame(Repeat=2, Date=231023, Transect="ew",
                       Receiver="iP6",
                       lon = as.numeric(iP6.2ew.coords["lon", ]),
                       lat = as.numeric(iP6.2ew.coords["lat",]))
nrow(iP6.ew.2.df)
ggplot(data=iP6.ew.2.df, aes(x=lon, y=lat))+geom_point() + 
  #scale_x_continuous(limits = c(-2.474950,-2.474850))+
  #scale_y_continuous(limits = c(53.450850,53.450950))+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.75)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.55,colour="red")
########
list.files(pattern="2024-01-16")

BES3ew.gpx <- htmlTreeParse(file = "2024-01-16 15_29_18 BES ew.gpx", useInternalNodes = TRUE)
BES3ew.coords <- xpathSApply(doc = BES3ew.gpx, path = "//trkpt", fun = xmlAttrs)
BES.ew.3.df <- data.frame(Repeat=3, Date=241023, Transect="ew",
                       Receiver="BES",
                       lon = as.numeric(BES3ew.coords["lon", ]),
                       lat = as.numeric(BES3ew.coords["lat",]))
ggplot(data=BES.ew.3.df, aes(x=lon, y=lat))+geom_point(cex=0.25)  + 
  #scale_x_continuous(limits = c(-2.474950,-2.474850))+
  #scale_y_continuous(limits = c(53.450850,53.450950))+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.75)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.55,colour="red")
####

BELC3ew.gpx <- htmlTreeParse(file = "2024-01-16 15_29_19 BELC ew.gpx", useInternalNodes = TRUE)
BELC3ew.coords <- xpathSApply(doc = BELC3ew.gpx, path = "//trkpt", fun = xmlAttrs)
BELC.ew.3.df <- data.frame(Repeat=3, Date=241023, Transect="ew",
                        Receiver="BELC",
                        lon = as.numeric(BELC3ew.coords["lon", ]),
                        lat = as.numeric(BELC3ew.coords["lat",]))
ggplot(data=BELC.ew.3.df, aes(x=lon, y=lat))+geom_point()  + 
  #scale_x_continuous(limits = c(-2.474950,-2.474850))+
  #scale_y_continuous(limits = c(53.450850,53.450950))+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.75)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.55,colour="red")
####

iP12.3ew.gpx <- htmlTreeParse(file = "2024-01-16 15_29_22 iP12 ew.gpx", useInternalNodes = TRUE)
iP12.3ew.coords <- xpathSApply(doc = iP12.3ew.gpx, path = "//trkpt", fun = xmlAttrs)
iP12.ew.3.df <- data.frame(Repeat=3, Date=241023, Transect="ew",
                        Receiver="iP12",
                        lon = as.numeric(iP12.3ew.coords["lon", ]),
                        lat = as.numeric(iP12.3ew.coords["lat",]))
ggplot(data=iP12.ew.3.df, aes(x=lon, y=lat))+geom_point()  + 
  #scale_x_continuous(limits = c(-2.474950,-2.474850))+
  #scale_y_continuous(limits = c(53.450850,53.450950))+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.75)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.55,colour="red")
####

iP6.3ew.gpx <- htmlTreeParse(file = "2024-01-16 15_29_20 iP6 ew.gpx", useInternalNodes = TRUE)
iP6.3ew.coords <- xpathSApply(doc = iP6.3ew.gpx, path = "//trkpt", fun = xmlAttrs)
iP6.ew.3.df <- data.frame(Repeat=3, Date=241023, Transect="ew",
                       Receiver="iP6",
                       lon = as.numeric(iP6.3ew.coords["lon", ]),
                       lat = as.numeric(iP6.3ew.coords["lat",]))
ggplot(data=iP6.ew.3.df, aes(x=lon, y=lat))+geom_point()+ 
  #scale_x_continuous(limits = c(-2.474950,-2.474850))+
  #scale_y_continuous(limits = c(53.450850,53.450950))+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.75)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.55,colour="red")
####

list.files(pattern="2024-01-17")

BES4ew.gpx <- htmlTreeParse(file = "2024-01-17 14_54_33 BES ew .gpx", useInternalNodes = TRUE)
BES4ew.coords <- xpathSApply(doc = BES4ew.gpx, path = "//trkpt", fun = xmlAttrs)
BES.ew.4.df <- data.frame(Repeat=4, Date=251023, Transect="ew",
                       Receiver="BES",
                       lon = as.numeric(BES4ew.coords["lon", ]),
                       lat = as.numeric(BES4ew.coords["lat",]))
ggplot(data=BES.ew.4.df, aes(x=lon, y=lat))+geom_point()  + 
  #scale_x_continuous(limits = c(-2.474950,-2.474850))+
  #scale_y_continuous(limits = c(53.450850,53.450950))+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.75)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.55,colour="red")
####

BELC4ew.gpx <- htmlTreeParse(file = "2024-01-17 14_54_34 BELC ew.gpx", useInternalNodes = TRUE)
BELC4ew.coords <- xpathSApply(doc = BELC4ew.gpx, path = "//trkpt", fun = xmlAttrs)
BELC.ew.4.df <- data.frame(Repeat=4, Date=251023, Transect="ew",
                        Receiver="BELC",
                        lon = as.numeric(BELC4ew.coords["lon", ]),
                        lat = as.numeric(BELC4ew.coords["lat",]))
ggplot(data=BELC.ew.4.df, aes(x=lon, y=lat))+geom_point()  + 
  #scale_x_continuous(limits = c(-2.474950,-2.474850))+
  #scale_y_continuous(limits = c(53.450850,53.450950))+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.75)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.55,colour="red")
####

iP12ew.4.gpx <- htmlTreeParse(file = "2024-01-17 14_54_36 iP12 ew.gpx", useInternalNodes = TRUE)
iP12ew.4.coords <- xpathSApply(doc = iP12ew.4.gpx, path = "//trkpt", fun = xmlAttrs)
iP12.ew.4.df <- data.frame(Repeat=4, Date=251023, Transect="ew",
                        Receiver="iP12",
                        lon = as.numeric(iP12ew.4.coords["lon", ]),
                        lat = as.numeric(iP12ew.4.coords["lat",]))
ggplot(data=iP12.ew.4.df, aes(x=lon, y=lat))+geom_point()  + 
  #scale_x_continuous(limits = c(-2.474950,-2.474850))+
  #scale_y_continuous(limits = c(53.450850,53.450950))+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.75)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.55,colour="red")
####

iP6ew.4.gpx <- htmlTreeParse(file = "2024-01-17 14_54_35 iP6 ew.gpx", useInternalNodes = TRUE)
iP6ew.4.coords <- xpathSApply(doc = iP6ew.4.gpx, path = "//trkpt", fun = xmlAttrs)
iP6.ew.4.df <- data.frame(Repeat=4, Date=251023, Transect="ew",
                       Receiver="iP6",
                       lon = as.numeric(iP6ew.4.coords["lon", ]),
                       lat = as.numeric(iP6ew.4.coords["lat",]))
ggplot(data=iP6.ew.4.df, aes(x=lon, y=lat))+geom_point()  + 
  #scale_x_continuous(limits = c(-2.474950,-2.474850))+
  #scale_y_continuous(limits = c(53.450850,53.450950))+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.75)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.55,colour="red")
####

list.files(pattern="2024-01-19")

BES5ew.gpx <- htmlTreeParse(file = "2024-01-19 11_54_43 BES ew.gpx", useInternalNodes = TRUE)
BES5ew.coords <- xpathSApply(doc = BES5ew.gpx, path = "//trkpt", fun = xmlAttrs)
BES.ew.5.df <- data.frame(Repeat=5, Date=261023, Transect="ew",
                       Receiver="BES",
                       lon = as.numeric(BES5ew.coords["lon", ]),
                       lat = as.numeric(BES5ew.coords["lat",]))
ggplot(data=BES.ew.5.df, aes(x=lon, y=lat))+geom_point()  + 
  #scale_x_continuous(limits = c(-2.474950,-2.474850))+
  #scale_y_continuous(limits = c(53.450850,53.450950))+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.75)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.55,colour="red")
####

BELC5ew.gpx <- htmlTreeParse(file = "2024-01-19 11_54_40 BELC ew.gpx", useInternalNodes = TRUE)
BELC5ew.coords <- xpathSApply(doc = BELC5ew.gpx, path = "//trkpt", fun = xmlAttrs)
BELC.ew.5.df <- data.frame(Repeat=5, Date=261023, Transect="ew",
                        Receiver="BELC",
                        lon = as.numeric(BELC5ew.coords["lon", ]),
                        lat = as.numeric(BELC5ew.coords["lat",]))
ggplot(data=BELC.ew.5.df, aes(x=lon, y=lat))+geom_point()  + 
  #scale_x_continuous(limits = c(-2.474950,-2.474850))+
  #scale_y_continuous(limits = c(53.450850,53.450950))+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.75)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.55,colour="red")
####

iP12ew.5.gpx <- htmlTreeParse(file = "2024-01-19 11_54_40 iP12 ew.gpx", useInternalNodes = TRUE)
iP12ew.5.coords <- xpathSApply(doc = iP12ew.5.gpx, path = "//trkpt", fun = xmlAttrs)
iP12.ew.5.df <- data.frame(Repeat=5, Date=261023, Transect="ew",
                        Receiver="iP12",
                        lon = as.numeric(iP12ew.5.coords["lon", ]),
                        lat = as.numeric(iP12ew.5.coords["lat",]))
ggplot(data=iP12.ew.5.df, aes(x=lon, y=lat))+geom_point()  + 
  #scale_x_continuous(limits = c(-2.474950,-2.474850))+
  #scale_y_continuous(limits = c(53.450850,53.450950))+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.75)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.55,colour="red")
####

iP6ew.5.gpx <- htmlTreeParse(file = "2024-01-19 11_54_40 iP6 ew.gpx", useInternalNodes = TRUE)
iP6ew.5.coords <- xpathSApply(doc = iP6ew.5.gpx, path = "//trkpt", fun = xmlAttrs)
iP6.ew.5.df <- data.frame(Repeat=5, Date=310523, Transect="ew",
                       Receiver="iP6",
                       lon = as.numeric(iP6ew.5.coords["lon", ]),
                       lat = as.numeric(iP6ew.5.coords["lat",]))
ggplot(data=iP6.ew.5.df, aes(x=lon, y=lat))+geom_point()  + 
  #scale_x_continuous(limits = c(-2.474950,-2.474850))+
  #scale_y_continuous(limits = c(53.450850,53.450950))+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.75)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.55,colour="red")

#######

EW_TX <-rbind(BES.ew.1.df,BELC.ew.1.df,iP12.ew.1.df,iP6.ew.1.df,
             BES.ew.2.df,BELC.ew.2.df,iP12.ew.2.df,iP6.ew.2.df,
             BES.ew.3.df,BELC.ew.3.df,iP12.ew.3.df,iP6.ew.3.df,
             BES.ew.4.df,BELC.ew.4.df,iP12.ew.4.df,iP6.ew.4.df,
             BES.ew.5.df,BELC.ew.5.df,iP12.ew.5.df,iP6.ew.5.df)
names(EW_TX)
##############################
ggplot(data=EW_TX, aes(x=lon, y=lat,colour=Receiver))+geom_point(size=0.5)+
  theme_bw()+
  #scale_x_continuous(limits = c(-2.474950,-2.474850))+
  #scale_y_continuous(limits = c(53.450850,53.450950))+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.75)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.55,colour="red")+
  annotate("pointrange", x = ew.x, y = ew.y, 
           ymin = ew.ymin , ymax = ew.ymax,
           colour = "red", size = 0.75)+
  geom_segment(x=ew.xmin, y=ew.y, xend=ew.xmax, yend=ew.y,size=0.55,colour="red")
###############################

#Geometry and Trig.
#Easting and Northing coordinates of ew (m)
 ew.E <- ((ew.x-x))/0.0000150523;ew.E# Easting of ew (m)
 ew.N <- ((ew.y-y))/0.0000089851;ew.N# Northing of ew (m)
 #ewsn is at 0 East and 0 west
 
 #work out the perpendicular distance "d" of the measurement from the transect across a data.frame
 EW_T <-EW_TX 
 names(EW_T)
 nrow(EW_T)
 #Convert lon-lat into Easting and Northing in meters
 EW_T$EAST <-((EW_T$lon-x)/0.0000150523)#meters east of ewsn of each measurement
 EW_T$NORTH <-((EW_T$lat-y)/0.0000089851)#meters north of ewsn of each measurement
 #Plot Easting and Northing coordinates (m)
 plot(EW_T$NORTH~EW_T$EAST)
 #work out the side lengths of the triangle; 
 #ewsn - ew (the transect) = base "b"
 # the measurement - ewsn = hypotenuse "h" 
 # the measurement - ew = abscissa "a", ie the opposite side
 EW_T$b <-rep((sqrt(((ew.E-0)^2)+((ew.N-0)^2))),times=3477)#sets length of transect in each row (b)
 EW_T$h = sqrt(((EW_T$EAST-0)^2)+((EW_T$NORTH-0)^2))#hypoteneuse - distance from ewsn of each measurement (h)
 EW_T$a = sqrt(((EW_T$EAST-ew.E)^2)+((EW_T$NORTH-ew.N)^2)) #opposite side - distance from ewsn of each measurement (h)
 #Work out the angle between the transect(side b) - ewsn - the measurement point (side h)
 EW_T$A <-(acos(((EW_T$b^2)+(EW_T$h^2)-(EW_T$a^2))/(2*EW_T$b*EW_T$h)))
 nrow(EW_T)
 #Work out "d" the perpendicular distance from the baseline (b)
 EW_T$d <- EW_T$h*sin(EW_T$A)
 names(EW_T)
 summary(EW_T$d)
#############################################################
 ##Plots
 library(ggplot2)
 names(EW_T) 
 
 ggplot(EW_T, aes(x=lon, y=lat, colour=Receiver))+
   geom_point()+theme_bw()
   #geom_segment(x=1, y=-0.07, xend=1, yend=2,size=0.05,colour="black",linetype=2)+
   #annotate(geom="text", x = 0.75, y = 1.7, 
    #        label="Radial Distance = 1 m", angle=90,
     #       colour = "black")
 
 
 ggplot(EW_T, aes(x=d,colour=Receiver,fill=Receiver)) + xlab("Distance (m)")+
   geom_density(alpha=0.4)+theme_bw()+
   geom_segment(x=1, y=-0.07, xend=1, yend=2,size=0.05,colour="black",linetype=2)+
   annotate(geom="text", x = 0.75, y = 1.7, 
            label="Distance = 1 m", angle=90,
            colour = "black")
 
 boxplot(d~Receiver, data=EW_T,
         ylab="Distance from transect (m)")
 #####################################################
 
 #Data processing for South-North transect
 list.files(pattern="2024-01-14")

 BES1sn.gpx <- htmlTreeParse(file = "2024-01-14 16_20_05 BES sn.gpx", useInternalNodes = TRUE)
 BES1sn.coords <- xpathSApply(doc = BES1sn.gpx, path = "//trkpt", fun = xmlAttrs)
 BES.sn.1.df <- data.frame(Repeat=1, Date=151023,Receiver="BES", Transect="sn",
                           lon = as.numeric(BES1sn.coords["lon", ]),
                           lat = as.numeric(BES1sn.coords["lat",]))
 ggplot(data=BES.sn.1.df, aes(x=lon, y=lat))+geom_point() + 
   #scale_x_continuous(limits = c(-2.474950,-2.474850))+
   #scale_y_continuous(limits = c(53.450850,53.450950))+
   annotate("pointrange", x = x, y = y, 
            ymin = ymin , ymax = ymax,
            colour = "red", size = 0.75)+
   geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.55,colour="red")
 
 ####
 BELC1sn.gpx <- htmlTreeParse(file = "2024-01-14 16_20_01 BELC sn.gpx", useInternalNodes = TRUE)
 BELC1sn.coords <- xpathSApply(doc = BELC1sn.gpx, path = "//trkpt", fun = xmlAttrs)
 BELC.sn.1.df <- data.frame(Repeat=1, Date=151023, Transect="sn",
                            Receiver="BELC",
                            lon = as.numeric(BELC1sn.coords["lon", ]),
                            lat = as.numeric(BELC1sn.coords["lat",])
 )

 ggplot(data=BELC.sn.1.df, aes(x=lon, y=lat))+geom_point()  + 
   #scale_x_continuous(limits = c(-2.474950,-2.474850))+
   #scale_y_continuous(limits = c(53.450850,53.450950))+
   annotate("pointrange", x = x, y = y, 
            ymin = ymin , ymax = ymax,
            colour = "red", size = 0.75)+
   geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.55,colour="red")
 
 ####
 iP12.1sn.gpx <- htmlTreeParse(file = "2024-01-14 16_20_02 iP12 sn .gpx", useInternalNodes = TRUE)
 iP12.1sn.coords <- xpathSApply(doc = iP12.1sn.gpx, path = "//trkpt", fun = xmlAttrs)
 iP12.sn.1.df <- data.frame(Repeat=1, Date=151023, Transect="sn",
                            Receiver="iP12",
                            lon = as.numeric(iP12.1sn.coords["lon", ]),
                            lat = as.numeric(iP12.1sn.coords["lat",])
 )

 ggplot(data=iP12.sn.1.df, aes(x=lon, y=lat))+geom_point() + 
   #scale_x_continuous(limits = c(-2.474950,-2.474850))+
   #scale_y_continuous(limits = c(53.450850,53.450950))+
   annotate("pointrange", x = x, y = y, 
            ymin = ymin , ymax = ymax,
            colour = "red", size = 0.75)+
   geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.55,colour="red")
 
 ####
 iP6.1sn.gpx <- htmlTreeParse(file = "2024-01-14 16_20_03 iP6 sn .gpx", useInternalNodes = TRUE)
 iP6.1sn.coords <- xpathSApply(doc = iP6.1sn.gpx, path = "//trkpt", fun = xmlAttrs)
 iP6.sn.1.df <- data.frame(Repeat=1, Date=151023, Transect ="sn",
                           Receiver="iP6",
                           lon = as.numeric(iP6.1sn.coords["lon", ]),
                           lat = as.numeric(iP6.1sn.coords["lat",])
 )
 ggplot(data=iP6.sn.1.df, aes(x=lon, y=lat))+geom_point() + 
   #scale_x_continuous(limits = c(-2.474950,-2.474850))+
   #scale_y_continuous(limits = c(53.450850,53.450950))+
   annotate("pointrange", x = x, y = y, 
            ymin = ymin , ymax = ymax,
            colour = "red", size = 0.75)+
   geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.55,colour="red")
 
 ########
 list.files(pattern="2024-01-15")
 
 BES2sn.gpx <- htmlTreeParse(file = "2024-01-15 14_34_13 BES sn .gpx", useInternalNodes = TRUE)
 BES2sn.coords <- xpathSApply(doc = BES2sn.gpx, path = "//trkpt", fun = xmlAttrs)
 BES.sn.2.df <- data.frame(Repeat=2, Date=251023,Receiver="BES", Transect="sn",
                           lon = as.numeric(BES2sn.coords["lon", ]),
                           lat = as.numeric(BES2sn.coords["lat",]))
 nrow(BES.sn.2.df)
 ggplot(data=BES.sn.2.df, aes(x=lon, y=lat))+geom_point(cex=0.25) + 
   #scale_x_continuous(limits = c(-2.474950,-2.474850))+
   #scale_y_continuous(limits = c(53.450850,53.450950))+
   annotate("pointrange", x = x, y = y, 
            ymin = ymin , ymax = ymax,
            colour = "red", size = 0.75)+
   geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.55,colour="red")
 
 ####
 BELC2sn.gpx <- htmlTreeParse(file = "2024-01-15 14_34_10 BELC sn.gpx", useInternalNodes = TRUE)
 BELC2sn.coords <- xpathSApply(doc = BELC2sn.gpx, path = "//trkpt", fun = xmlAttrs)
 BELC.sn.2.df <- data.frame(Repeat=2, Date=221023, Transect="sn",
                            Receiver="BELC",
                            lon = as.numeric(BELC2sn.coords["lon", ]),
                            lat = as.numeric(BELC2sn.coords["lat",]))
 nrow(BELC.sn.2.df)
 ggplot(data=BELC.sn.2.df, aes(x=lon, y=lat))+geom_point() + 
   #scale_x_continuous(limits = c(-2.474950,-2.474850))+
   #scale_y_continuous(limits = c(53.450850,53.450950))+
   annotate("pointrange", x = x, y = y, 
            ymin = ymin , ymax = ymax,
            colour = "red", size = 0.75)+
   geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.55,colour="red")
 
 ####
 iP12.2sn.gpx <- htmlTreeParse(file = "2024-01-15 14_34_12 iP12 sn .gpx", useInternalNodes = TRUE)
 iP12.2sn.coords <- xpathSApply(doc = iP12.2sn.gpx, path = "//trkpt", fun = xmlAttrs)
 iP12.sn.2.df <- data.frame(Repeat=2, Date=231023, Transect="sn",
                            Receiver="iP12",
                            lon = as.numeric(iP12.2sn.coords["lon", ]),
                            lat = as.numeric(iP12.2sn.coords["lat",]))
 nrow(iP12.sn.2.df)
 ggplot(data=iP12.sn.2.df, aes(x=lon, y=lat))+geom_point() + 
   #scale_x_continuous(limits = c(-2.474950,-2.474850))+
   #scale_y_continuous(limits = c(53.450850,53.450950))+
   annotate("pointrange", x = x, y = y, 
            ymin = ymin , ymax = ymax,
            colour = "red", size = 0.75)+
   geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.55,colour="red")
 
 ####
 iP6.2sn.gpx <- htmlTreeParse(file = "2024-01-15 14_34_10 iP6 sn .gpx", useInternalNodes = TRUE)
 iP6.2sn.coords <- xpathSApply(doc = iP6.2sn.gpx, path = "//trkpt", fun = xmlAttrs)
 iP6.sn.2.df <- data.frame(Repeat=2, Date=231023, Transect="sn",
                           Receiver="iP6",
                           lon = as.numeric(iP6.2sn.coords["lon", ]),
                           lat = as.numeric(iP6.2sn.coords["lat",]))
 nrow(iP6.sn.2.df)
 ggplot(data=iP6.sn.2.df, aes(x=lon, y=lat))+geom_point() + 
   #scale_x_continuous(limits = c(-2.474950,-2.474850))+
   #scale_y_continuous(limits = c(53.450850,53.450950))+
   annotate("pointrange", x = x, y = y, 
            ymin = ymin , ymax = ymax,
            colour = "red", size = 0.75)+
   geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.55,colour="red")
 ########
 list.files(pattern="2024-01-16")
 
 BES3sn.gpx <- htmlTreeParse(file = "2024-01-16 15_32_58 BES sn.gpx", useInternalNodes = TRUE)
 BES3sn.coords <- xpathSApply(doc = BES3sn.gpx, path = "//trkpt", fun = xmlAttrs)
 BES.sn.3.df <- data.frame(Repeat=3, Date=241023, Transect="sn",
                           Receiver="BES",
                           lon = as.numeric(BES3sn.coords["lon", ]),
                           lat = as.numeric(BES3sn.coords["lat",]))
 ggplot(data=BES.sn.3.df, aes(x=lon, y=lat))+geom_point(cex=0.25)  + 
   #scale_x_continuous(limits = c(-2.474950,-2.474850))+
   #scale_y_continuous(limits = c(53.450850,53.450950))+
   annotate("pointrange", x = x, y = y, 
            ymin = ymin , ymax = ymax,
            colour = "red", size = 0.75)+
   geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.55,colour="red")
 ####
 
 BELC3sn.gpx <- htmlTreeParse(file = "2024-01-16 15_32_59 BELC sn.gpx", useInternalNodes = TRUE)
 BELC3sn.coords <- xpathSApply(doc = BELC3sn.gpx, path = "//trkpt", fun = xmlAttrs)
 BELC.sn.3.df <- data.frame(Repeat=3, Date=241023, Transect="sn",
                            Receiver="BELC",
                            lon = as.numeric(BELC3sn.coords["lon", ]),
                            lat = as.numeric(BELC3sn.coords["lat",]))
 ggplot(data=BELC.sn.3.df, aes(x=lon, y=lat))+geom_point()  + 
   #scale_x_continuous(limits = c(-2.474950,-2.474850))+
   #scale_y_continuous(limits = c(53.450850,53.450950))+
   annotate("pointrange", x = x, y = y, 
            ymin = ymin , ymax = ymax,
            colour = "red", size = 0.75)+
   geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.55,colour="red")
 ####
 
 iP12.3sn.gpx <- htmlTreeParse(file = "2024-01-16 15_33_01 iP12 sn.gpx", useInternalNodes = TRUE)
 iP12.3sn.coords <- xpathSApply(doc = iP12.3sn.gpx, path = "//trkpt", fun = xmlAttrs)
 iP12.sn.3.df <- data.frame(Repeat=3, Date=241023, Transect="sn",
                            Receiver="iP12",
                            lon = as.numeric(iP12.3sn.coords["lon", ]),
                            lat = as.numeric(iP12.3sn.coords["lat",]))
 ggplot(data=iP12.sn.3.df, aes(x=lon, y=lat))+geom_point()  + 
   #scale_x_continuous(limits = c(-2.474950,-2.474850))+
   #scale_y_continuous(limits = c(53.450850,53.450950))+
   annotate("pointrange", x = x, y = y, 
            ymin = ymin , ymax = ymax,
            colour = "red", size = 0.75)+
   geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.55,colour="red")
 ####
 
 iP6.3sn.gpx <- htmlTreeParse(file = "2024-01-16 15_33_00 iP6 sn.gpx", useInternalNodes = TRUE)
 iP6.3sn.coords <- xpathSApply(doc = iP6.3sn.gpx, path = "//trkpt", fun = xmlAttrs)
 iP6.sn.3.df <- data.frame(Repeat=3, Date=241023, Transect="sn",
                           Receiver="iP6",
                           lon = as.numeric(iP6.3sn.coords["lon", ]),
                           lat = as.numeric(iP6.3sn.coords["lat",]))
 ggplot(data=iP6.sn.3.df, aes(x=lon, y=lat))+geom_point()+ 
   #scale_x_continuous(limits = c(-2.474950,-2.474850))+
   #scale_y_continuous(limits = c(53.450850,53.450950))+
   annotate("pointrange", x = x, y = y, 
            ymin = ymin , ymax = ymax,
            colour = "red", size = 0.75)+
   geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.55,colour="red")
 ####
 
 list.files(pattern="2024-01-17")
 
 BES4sn.gpx <- htmlTreeParse(file = "2024-01-17 14_59_18 BES sn.gpx", useInternalNodes = TRUE)
 BES4sn.coords <- xpathSApply(doc = BES4sn.gpx, path = "//trkpt", fun = xmlAttrs)
 BES.sn.4.df <- data.frame(Repeat=4, Date=251023, Transect="sn",
                           Receiver="BES",
                           lon = as.numeric(BES4sn.coords["lon", ]),
                           lat = as.numeric(BES4sn.coords["lat",]))
 ggplot(data=BES.sn.4.df, aes(x=lon, y=lat))+geom_point()  + 
   #scale_x_continuous(limits = c(-2.474950,-2.474850))+
   #scale_y_continuous(limits = c(53.450850,53.450950))+
   annotate("pointrange", x = x, y = y, 
            ymin = ymin , ymax = ymax,
            colour = "red", size = 0.75)+
   geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.55,colour="red")
 ####
 
 BELC4sn.gpx <- htmlTreeParse(file = "2024-01-17 14_59_19 BELC sn.gpx", useInternalNodes = TRUE)
 BELC4sn.coords <- xpathSApply(doc = BELC4sn.gpx, path = "//trkpt", fun = xmlAttrs)
 BELC.sn.4.df <- data.frame(Repeat=4, Date=251023, Transect="sn",
                            Receiver="BELC",
                            lon = as.numeric(BELC4sn.coords["lon", ]),
                            lat = as.numeric(BELC4sn.coords["lat",]))
 ggplot(data=BELC.sn.4.df, aes(x=lon, y=lat))+geom_point()  + 
   #scale_x_continuous(limits = c(-2.474950,-2.474850))+
   #scale_y_continuous(limits = c(53.450850,53.450950))+
   annotate("pointrange", x = x, y = y, 
            ymin = ymin , ymax = ymax,
            colour = "red", size = 0.75)+
   geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.55,colour="red")
 ####
 
 iP12sn.4.gpx <- htmlTreeParse(file = "2024-01-17 14_59_21 iP12 sn.gpx", useInternalNodes = TRUE)
 iP12sn.4.coords <- xpathSApply(doc = iP12sn.4.gpx, path = "//trkpt", fun = xmlAttrs)
 iP12.sn.4.df <- data.frame(Repeat=4, Date=251023, Transect="sn",
                            Receiver="iP12",
                            lon = as.numeric(iP12sn.4.coords["lon", ]),
                            lat = as.numeric(iP12sn.4.coords["lat",]))
 ggplot(data=iP12.sn.4.df, aes(x=lon, y=lat))+geom_point()  + 
   #scale_x_continuous(limits = c(-2.474950,-2.474850))+
   #scale_y_continuous(limits = c(53.450850,53.450950))+
   annotate("pointrange", x = x, y = y, 
            ymin = ymin , ymax = ymax,
            colour = "red", size = 0.75)+
   geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.55,colour="red")
 ####
 
 iP6sn.4.gpx <- htmlTreeParse(file = "2024-01-17 14_59_20 iP6 sn .gpx", useInternalNodes = TRUE)
 iP6sn.4.coords <- xpathSApply(doc = iP6sn.4.gpx, path = "//trkpt", fun = xmlAttrs)
 iP6.sn.4.df <- data.frame(Repeat=4, Date=251023, Transect="sn",
                           Receiver="iP6",
                           lon = as.numeric(iP6sn.4.coords["lon", ]),
                           lat = as.numeric(iP6sn.4.coords["lat",]))
 ggplot(data=iP6.sn.4.df, aes(x=lon, y=lat))+geom_point()  + 
   #scale_x_continuous(limits = c(-2.474950,-2.474850))+
   #scale_y_continuous(limits = c(53.450850,53.450950))+
   annotate("pointrange", x = x, y = y, 
            ymin = ymin , ymax = ymax,
            colour = "red", size = 0.75)+
   geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.55,colour="red")
 ####
 
 list.files(pattern="2024-01-19")
 
 BES5sn.gpx <- htmlTreeParse(file = "2024-01-19 11_59_23 BES sn.gpx", useInternalNodes = TRUE)
 BES5sn.coords <- xpathSApply(doc = BES5sn.gpx, path = "//trkpt", fun = xmlAttrs)
 BES.sn.5.df <- data.frame(Repeat=5, Date=261023, Transect="sn",
                           Receiver="BES",
                           lon = as.numeric(BES5sn.coords["lon", ]),
                           lat = as.numeric(BES5sn.coords["lat",]))
 ggplot(data=BES.sn.5.df, aes(x=lon, y=lat))+geom_point()  + 
   #scale_x_continuous(limits = c(-2.474950,-2.474850))+
   #scale_y_continuous(limits = c(53.450850,53.450950))+
   annotate("pointrange", x = x, y = y, 
            ymin = ymin , ymax = ymax,
            colour = "red", size = 0.75)+
   geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.55,colour="red")
 ####
 
 BELC5sn.gpx <- htmlTreeParse(file = "2024-01-19 11_59_20 BELC sn.gpx", useInternalNodes = TRUE)
 BELC5sn.coords <- xpathSApply(doc = BELC5sn.gpx, path = "//trkpt", fun = xmlAttrs)
 BELC.sn.5.df <- data.frame(Repeat=5, Date=261023, Transect="sn",
                            Receiver="BELC",
                            lon = as.numeric(BELC5sn.coords["lon", ]),
                            lat = as.numeric(BELC5sn.coords["lat",]))
 ggplot(data=BELC.sn.5.df, aes(x=lon, y=lat))+geom_point()  + 
   #scale_x_continuous(limits = c(-2.474950,-2.474850))+
   #scale_y_continuous(limits = c(53.450850,53.450950))+
   annotate("pointrange", x = x, y = y, 
            ymin = ymin , ymax = ymax,
            colour = "red", size = 0.75)+
   geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.55,colour="red")
 ####
 
 iP12sn.5.gpx <- htmlTreeParse(file = "2024-01-19 11_59_22 iP12 sn.gpx", useInternalNodes = TRUE)
 iP12sn.5.coords <- xpathSApply(doc = iP12sn.5.gpx, path = "//trkpt", fun = xmlAttrs)
 iP12.sn.5.df <- data.frame(Repeat=5, Date=261023, Transect="sn",
                            Receiver="iP12",
                            lon = as.numeric(iP12sn.5.coords["lon", ]),
                            lat = as.numeric(iP12sn.5.coords["lat",]))
 ggplot(data=iP12.sn.5.df, aes(x=lon, y=lat))+geom_point()  + 
   #scale_x_continuous(limits = c(-2.474950,-2.474850))+
   #scale_y_continuous(limits = c(53.450850,53.450950))+
   annotate("pointrange", x = x, y = y, 
            ymin = ymin , ymax = ymax,
            colour = "red", size = 0.75)+
   geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.55,colour="red")
 ####
 
 iP6sn.5.gpx <- htmlTreeParse(file = "2024-01-19 11_59_20 iP6 sn.gpx", useInternalNodes = TRUE)
 iP6sn.5.coords <- xpathSApply(doc = iP6sn.5.gpx, path = "//trkpt", fun = xmlAttrs)
 iP6.sn.5.df <- data.frame(Repeat=5, Date=310523, Transect="sn",
                           Receiver="iP6",
                           lon = as.numeric(iP6sn.5.coords["lon", ]),
                           lat = as.numeric(iP6sn.5.coords["lat",]))
 ggplot(data=iP6.sn.5.df, aes(x=lon, y=lat))+geom_point()  + 
   #scale_x_continuous(limits = c(-2.474950,-2.474850))+
   #scale_y_continuous(limits = c(53.450850,53.450950))+
   annotate("pointrange", x = x, y = y, 
            ymin = ymin , ymax = ymax,
            colour = "red", size = 0.75)+
   geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.55,colour="red")

 #######
 
 SN_TX <-rbind(BES.sn.1.df,BELC.sn.1.df,iP12.sn.1.df,iP6.sn.1.df,
               BES.sn.2.df,BELC.sn.2.df,iP12.sn.2.df,iP6.sn.2.df,
               BES.sn.3.df,BELC.sn.3.df,iP12.sn.3.df,iP6.sn.3.df,
               BES.sn.4.df,BELC.sn.4.df,iP12.sn.4.df,iP6.sn.4.df,
               BES.sn.5.df,BELC.sn.5.df,iP12.sn.5.df,iP6.sn.5.df)
 names(SN_TX)
 nrow(SN_TX)
 #################################################
 #sn coordinates from Trimble data with Wilton-Jones transformation
 sn.x= -2.4748041248861
 sn.y= 53.4508116952
 #Deduce Lat difference for 1m radius on y axis
 sn.Y=data.frame(sn.x,sn.y+0.0000089851)
 sn.Y <-as.matrix(sn.Y)
 1000*(spDistsN1(pts=sn.Y,pt=c(sn.x,sn.y),longlat=TRUE))
 sn.ymin=(sn.y-0.0000090);sn.ymin#53.4507969
 sn.ymax=(sn.y+0.0000090);sn.ymax#53.4508149
 
 #Deduce Lon difference for 1m radius on x axis
 sn.X=data.frame(sn.x+0.0000150523,sn.y)
 sn.X <-as.matrix(sn.X)
 1000*(spDistsN1(pts=sn.X,pt=c(sn.x,sn.y),longlat=TRUE))
 sn.xmin=(sn.x-0.0000151);sn.xmin#-2.47482711
 sn.xmax=(sn.x+0.0000151);sn.xmax#-2.47479691
 ##############################
 ggplot(data=SN_TX, aes(x=lon, y=lat,colour=Receiver))+geom_point(size=0.5)+
   theme_bw()+
   #scale_x_continuous(limits = c(-2.474950,-2.474850))+
   #scale_y_continuous(limits = c(53.450850,53.450950))+
   annotate("pointrange", x = x, y = y, 
            ymin = ymin , ymax = ymax,
            colour = "red", size = 0.75)+
   geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.55,colour="red")+
   annotate("pointrange", x = sn.x, y = sn.y, 
            ymin = sn.ymin , ymax = sn.ymax,
            colour = "red", size = 0.75)+
   geom_segment(x=sn.xmin, y=sn.y, xend=sn.xmax, yend=sn.y,size=0.55,colour="red")
 ###############################
 
 #Geometry and Trig.
 #Easting and Northing coordinates of sn (m)
 sn.E <- ((sn.x-x))/0.0000150523;sn.E# Easting of sn (m)
 sn.N <- ((sn.y-y))/0.0000089851;sn.N# Northing of sn (m)
 #ewsn is at 0 East and 0 west
 
 #work out the perpendicular distance "d" of the measurement from the transect across a data.frame
 SN_T <-SN_TX 
 names(SN_T)
 nrow(SN_T)
 #Convert lon-lat into Easting and Northing in meters
 SN_T$EAST <-((SN_T$lon-x)/0.0000150523)#meters east of ewsn of each measurement
 SN_T$NORTH <-((SN_T$lat-y)/0.0000089851)#meters north of ewsn of each measurement
 #Plot Easting and Northing coordinates (m)
 plot(SN_T$NORTH~SN_T$EAST)
 #work out the side lengths of the triangle; 
 #ewsn - ew (the transect) = base "b"
 # the measurement - ewsn = hypotenuse "h" 
 # the measurement - ew = abscissa "a", ie the opposite side
 SN_T$b <-rep((sqrt(((sn.E-0)^2)+((sn.N-0)^2))),times=3401)#sets length of transect in each row (b)
 SN_T$h = sqrt(((SN_T$EAST-0)^2)+((SN_T$NORTH-0)^2))#hypoteneuse - distance from ewsn of each measurement (h)
 SN_T$a = sqrt(((SN_T$EAST-sn.E)^2)+((SN_T$NORTH-sn.N)^2)) #opposite side - distance from ewsn of each measurement (h)
 #Work out the angle between the transect(side b) - ewsn - the measurement point (side h)
 SN_T$A <-(acos(((SN_T$b^2)+(SN_T$h^2)-(SN_T$a^2))/(2*SN_T$b*SN_T$h)))
 nrow(SN_T)
 #Work out "d" the perpendicular distance from the baseline (b)
 SN_T$d <- SN_T$h*sin(SN_T$A)
 names(SN_T)
 summary(SN_T$d)
 #############################################################
 ##Density plot
 library(ggplot2)
 names(SN_T) 

 ggplot(SN_T, aes(x=d,colour=Receiver,fill=Receiver)) + xlab("Distance (m)")+
   geom_density(alpha=0.4)+theme_bw()+
   geom_segment(x=1, y=-0.07, xend=1, yend=2,size=0.05,colour="black",linetype=2)+
   annotate(geom="text", x = 0.75, y = 1.7, 
            label="Distance = 1 m", angle=90,
            colour = "black")
 
 boxplot(d~Receiver, data=SN_T,
         ylab="Distance from transect (m)") 

 ###################################################
 #Merge distances from EW_T and SN_T
 
 EWSN_T <-rbind(EW_T,SN_T)

 #write .csv file
 setwd("~/Desktop/PC_Folders/LHB/Manuscripts/GPS_Calibration/GPS_Data_Processing")
 write.csv(EWSN_T,"Walked_Transect_Survey.csv")
 ###################################################
