#### Accuracy of Smartphone and External Handheld GPS Receivers ####
#### Jan 2024 ####
#### PERMANOVA ####
############################################

#### The PERMANOVA analysis is highly resource intensive - 
#analysing of EWSN_F generates a 18343 x 18343 dissimilarity matrix which has to be held in RAM 
# and took us 6 hours on a research grade PC with 64Gb of RAM.
# The output of our workings from this R script are given in the attached file
# PERMANOVA_Output.txt ####



setwd("~/Desktop/PC_Folders/LHB/Manuscripts/GPS_Calibration/GPSCalibration_SupplementalData")
#Data files from the three Surveys
list.files(pattern=".csv")

library(vegan)
#library(devtools)
#install_github("pmartinezarbizu/pairwiseAdonis/pairwiseAdonis")
#force = TRUE
library(pairwiseAdonis)#not compatible with current versions of R
#install compatible version of R, we used R version 4.0.4
version
library(parallel)
detectCores()#set number of cores in adonis2 or pairwise.adonis2

#parallel speeds up processing if you have multiple processors, 
#although memory then become the critical limiting factor...
#set the number of cores in the adonis2 or pairwise.adonis2 function

options(digits=4)
options(scipen=999)

####Fixed Base-station Survey####
EWSN_F <-read.csv("Fixed_BaseStation_Survey.csv")

names(EWSN_F)
head(EWSN_F)
nrow(EWSN_F)

#Reduce the number of measurements if necessary.  
#Analysis of the large dataset is  highly resource intensive.
#Can use one measurement every 1,2,5,10,30 seconds? by=n
EWSN_F.new = EWSN_F[seq(from=1, to=nrow(EWSN_F), by=10), ]
names(EWSN_F.new)
head(EWSN_F.new)
nrow(EWSN_F.new)

EWSN_F.dist.perm <-adonis2(EWSN_F.new$Dist~Receiver*Repeat,
                           data=EWSN_F.new, method='euclidean',
                           parallel =12 , #set number of cores
                           permutations = 999)
EWSN_F.dist.perm
####
names(EWSN_F.new)
head(EWSN_F.new)
nrow(EWSN_F.new)
?adonis2
#Comparing overall performance of receivers, repeat measurements and their interaction
EWSN_F.dist.perm <-adonis2(EWSN_F.new$Dist~Receiver*Repeat,
                             data=EWSN_F.new, method='euclidean',
                            parallel = , #set number of cores
                           permutations = 999)
EWSN_F.dist.perm
write.table(EWSN_F.dist.perm,"EWSN_F.dist.perm.txt")

#comparing pairs of Receivers
?pairwise.adonis2
EWSN_F.dist.pw<-pairwise.adonis2(EWSN_F.new[7] ~ Receiver*Repeat,
                                   data=EWSN_F.new,
                                   strata='Receiver', 
                                 parallel = , #set number of cores
                                   sim.method='euclidean')
EWSN_F.dist.pw
write.table(EWSN_F.dist.pw,"EWSN_F.dist.pw.txt")


#############################################################
####Walked Transect Survey####
EWSN_T <-read.csv("Walked_Transect_Survey.csv")
names(EWSN_T)
range(EWSN_T$Repeat)
head(EWSN_T)
nrow(EWSN_T)
#Reduce the number of measurements if necessary.  
#Analysis of the large dataset is  highly resource intensive.
#Can use one measurement every 1,2,5,10,30 seconds? by=n
EWSN_T.new = EWSN_T[seq(from=1, to=nrow(EWSN_T), by=1), ]
names(EWSN_T.new)
nrow(EWSN_T.new)

#Comparing overall performance of receivers, repeat measurements and their interaction
EWSN_T.dist.perm <-adonis2(EWSN_T.new$d~Receiver*Repeat,
                           data=EWSN_T.new, 
                           parallel = , #set number of cores
                           method='euclidean')
EWSN_T.dist.perm
write.table(EWSN_T.dist.perm,"EWSN_T.dist.perm.txt")

#comparing pairs of Receivers
EWSN_T.dist.pw<-pairwise.adonis2(EWSN_T.new[14] ~ Receiver*Repeat,
                                 data=EWSN_T.new,
                                 strata='Receiver', 
                                 parallel = , #set number of cores
                                 sim.method='euclidean')
EWSN_T.dist.pw
write.table(EWSN_T.dist.pw,"EWSN_T.dist.pw.txt")


?aov
#############################################################
####Roaming Point Survey####
EWSN_R <-read.csv("Roaming_Point_Survey.csv")
names(EWSN_R)
head(EWSN_R)
nrow(EWSN_R)
#Reduce the number of measurements if necessary.  
#Analysis of the large dataset is  highly resource intensive.
#Can use one measurement every 1,2,5,10,30 seconds? by=n
EWSN_R.new = EWSN_R[seq(from=1, to=nrow(EWSN_R), by=1), ]
names(EWSN_R.new)
nrow(EWSN_R.new)

#Comparing overall performance of receivers, repeat measurements and their interaction
EWSN_R.dist.perm <-adonis2(EWSN_R.new$Dist~Receiver*Repeat,
                           data=EWSN_R.new, 
                           parallel = , #set number of cores
                           method='euclidean')
EWSN_R.dist.perm
write.table(EWSN_R.dist.perm,"EWSN_R.dist.perm.txt")


#comparing pairs of Receivers
EWSN_R.dist.pw<-pairwise.adonis2(EWSN_R.new[7] ~ Receiver*Repeat,
                                 data=EWSN_R.new,
                                 strata='Receiver', 
                                 parallel = , #set number of cores
                                 sim.method='euclidean')
EWSN_R.dist.pw
write.table(EWSN_R.dist.pw,"EWSN_R.dist.pw.txt")

##############################################################
