#### Accuracy of Smartphone and External Handheld GPS Receivers ####
#### Jan 2024 ####
#### Plots of GPS Points ####
####Density Plots####
############################################

library(ggplot2)
library(ggpubr)
library(scales)
#library(ggspatial)
#devtools::install_github('oswaldosantos/ggsn')
#library(ggsn)
#library(sf)
#install.packages("remotes")
#remotes::install_github("3wen/legendMap")
#library(legendMap)
options(digits=8)
options(scipen=999)

setwd("~/Desktop/PC_Folders/LHB/Manuscripts/GPS_Calibration/GPSCalibration_SupplementalData")
list.files()

#Base station coordinates from Trimble data
#ewsn coordinates

#ewsn Wilton-Jones CRS transformation
x=-2.4748789803808
y=53.450914719012
#Callibration circle radii ewsb base-station
#Lat difference for 2m radius on y axis
ymin=y-(2*0.0000090)
ymax=y+(2*0.0000090)
#Lon difference for 2m radius on x axis
xmin=x-(2*0.0000151)
xmax=x+(2*0.0000151)
#ew coordinates 
#Wilton-Jones CRS transformation
ew.x= -2.4747094849943
ew.y= 53.450964541335
#sn coordinates
#Wilton-Jones CRS transformation
sn.x= -2.4748041248861
sn.y= 53.4508116952

#Callibration circle radii ew
#Lat difference for 2m radius on y axis
ew.ymin=(ew.y-(2*0.0000090));ew.ymin
ew.ymax=(ew.y+(2*0.0000090));ew.ymax
#Lon difference for 2m radius on x axis
ew.xmin=(ew.x-(2*0.0000151));ew.xmin
ew.xmax=(ew.x+(2*0.0000151));ew.xmax

#Callibration circle radii sn
#Lat difference for 2m radius on y axis
sn.ymin=(sn.y-(2*0.0000090));sn.ymin
sn.ymax=(sn.y+(2*0.0000090));sn.ymax
#Lon difference for 2m radius on x axis
sn.xmin=(sn.x-(2*0.0000151));sn.xmin
sn.xmax=(sn.x+(2*0.0000151));sn.xmax

# Colour blind palette with black:
cbbPalette <- c("#0072B2","#000000", "#E69F00","#009E73")

####Fixed Point Survey####

EWSN_F <-read.csv("Fixed_BaseStation_Survey.csv")
#BES detail
?scale_x_continuous
BES_F <-subset(EWSN_F,Receiver=="BES")
BES_F.gg <-ggplot(data=BES_F, aes(x=lon, y=lat))+ theme_bw()+
  geom_jitter(pch=8, size=0.5,width=0.0000005,height=0.0000005)+ 
  coord_fixed(ratio=151/90)+
  scale_x_continuous(limits = c(-2.47492,-2.474845),labels = label_number(accuracy = 0.00001))+
  scale_y_continuous(labels = label_number(accuracy = 0.00001))+
  xlab("Longitude (degrees)")+ylab("Latitude (degrees)")+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.375)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.03,colour="red")+
  annotate(geom="text", x = x+0.000007, y = y-0.000001, 
           label="Base Station", angle=0,cex=5,
           colour = "red")+
  #plots a circular ellipse 2m in diameter, on the rectangular lon -lat grid
  annotate("path", colour = "red",size=0.375,
           x=x+2*0.0000151*cos(seq(0,2*pi,length.out=100)),
           y=y+2*0.0000090*sin(seq(0,2*pi,length.out=100)))+
  #plots a circular ellipse 1m in diameter, on the rectangular lon -lat grid
  annotate("path", colour = "red",size=0.375,
           lour = "red",size=0.375,
           x=x+0.0000151*cos(seq(0,2*pi,length.out=100)),
           y=y+0.0000090*sin(seq(0,2*pi,length.out=100)))+
  annotate(geom="text", x = x+0.000003, y = y-0.000010, 
           label="1 m", angle=0,cex=5,
           colour = "red")+
  annotate(geom="text", x = x+0.000003, y = y-0.000019 , 
           label="2 m", angle=0,cex=5,
           colour = "red")

##Add scale bars

Vertical=x-0.0000435
Level=y-0.000023

BES_F.S.gg <-BES_F.gg+

  #Horizontal scale
  geom_segment(x=x-(2*0.0000151), y=Level, 
               xend=x+(2*0.0000151), yend=Level,
               size=0.3,
               colour="black")+
  geom_segment(x=x-(2*0.0000151), y=Level, 
               xend=x-(2*0.0000151), yend=Level+0.000001,
               size=0.3,
               colour="black")+
  geom_segment(x=x-(1*0.0000151), y=Level, 
               xend=x-(1*0.0000151), yend=Level+0.0000005,
               size=0.3,
               colour="black")+
  geom_segment(x=x, y=Level, 
               xend=x, yend=Level+0.000001,
               size=0.3,
               colour="black")+
  geom_segment(x=x+(1.*0.0000151), y=Level, 
               xend=x+(1.*0.0000151), yend=Level+0.0000005,
               size=0.3,
               colour="black")+
  geom_segment(x=x+(2.*0.0000151), y=Level, 
               xend=x+(2.*0.0000151), yend=Level+0.000001,
               size=0.3,
               colour="black")+
  annotate(geom="text", x = x, y = Level+0.000002, 
           label="0", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = x-(2*0.0000151), y = Level+0.000002, 
           label="-2", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = x-(1*0.0000151), y = Level+0.000002, 
           label="-1", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = x+(1*0.0000151), y = Level+0.000002, 
           label="1", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = x+(2*0.0000151), y = Level+0.000002, 
           label="    2 m", angle=0,
           colour = "black", cex=5)+
  
  #Vertical scale
  geom_segment(x=Vertical, y=y-(2*0.0000090), 
               xend=Vertical, yend=y+(3*0.0000090),
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y, 
               xend=Vertical+0.00000168, yend=y,
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y-(2*0.0000090), 
               xend=Vertical+0.00000168, yend=y-(2*0.0000090),
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y-(1*0.0000090), 
               xend=Vertical+(0.00000168/2), yend=y-(1*0.0000090),
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y+(1*0.0000090), 
               xend=Vertical+(0.00000168/2), yend=y+(1*0.0000090),
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y+(2*0.0000090), 
               xend=Vertical+(0.00000168/2), yend=y+(2*0.0000090),
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y+(3*0.0000090), 
               xend=Vertical+(0.00000168), yend=y+(3*0.0000090),
               size=0.3,
               colour="black")+
  annotate(geom="text", x = Vertical+0.00000336, y = y, 
           label="0", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = Vertical+0.00000336, y = y-(1*0.0000090), 
           label="-1", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = Vertical+0.00000336, y = y-(2*0.0000090), 
           label="-2", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = Vertical+0.00000336, y = y+(1*0.0000090), 
           label="1", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = Vertical+0.00000336, y = y+(2*0.0000090), 
           label="2", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = Vertical+0.00000336, y = y+(3*0.0000090), 
           label="    3 m", angle=0,
           colour = "black", cex=5)

BES_F.S.gg
####

print(BES_F.gg, width=unit(1510/2,"points"), height=unit(900/2,"points"))

####
#Plot 4 Receivers
EWSN_F.gg <-
  ggplot(data=EWSN_F, aes(x=lon, y=lat,colour=Receiver))+ 
  geom_jitter(pch=8, size=0.5, width=0.000001,height=0.000001)+
  theme_bw()+ scale_colour_manual(values=cbbPalette)+
  xlab("Longitude (degrees)")+ylab("Latitude (degrees)")+
  guides(color=guide_legend(override.aes = list(size=c(2))))+
  coord_fixed(ratio=151/90)+
  scale_x_continuous(limits = c(-2.47495,-2.47468),labels = label_number(accuracy = 0.00001))+
  scale_y_continuous(labels = label_number(accuracy = 0.00001))+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.375)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.008,colour="red")+
  annotate(geom="text", x = x+0.000020, y = y-0.000004, 
           label="Base Station", angle=0,
           colour = "red")+
  annotate("path", colour = "red", size=0.375,
           x=x+0.0000151*cos(seq(0,2*pi,length.out=100)),
           y=y+0.0000090*sin(seq(0,2*pi,length.out=100)))+
  annotate("path", colour = "red", size=0.375,
           x=x+2*0.0000151*cos(seq(0,2*pi,length.out=100)),
           y=y+2*0.0000090*sin(seq(0,2*pi,length.out=100)))+
  annotate(geom="text", x = x+0.000005, y = y-0.000010, 
           label="1 m", angle=0,cex=5,
           colour = "red")+
  annotate(geom="text", x = x+0.000005, y = y-0.000019 , 
           label="2 m", angle=0,cex=5,
           colour = "red")
  
print(EWSN_F.gg, width=unit(15.1/2,"cm"), height=unit(9/2,"cm"))

##Add scale bars  

Vertical=x-0.000076
Level=y-0.0000402

EWSN_F.gg+
  #Horizontal scale
  geom_segment(x=x-(2*0.0000151), y=Level, 
               xend=x+(12*0.0000151), yend=Level,
               size=0.3,
               colour="black")+
  geom_segment(x=x-(2*0.0000151), y=Level, 
               xend=x-(2*0.0000151), 
               yend=Level+0.000001,
               size=0.3,
               colour="black")+
  geom_segment(x=x, y=Level, 
               xend=x, yend=Level+0.000001,
               size=0.3,
               colour="black")+
  geom_segment(x=x+(2.*0.0000151), y=Level, 
               xend=x+(2.*0.0000151), yend=Level+0.000001,
               size=0.3,
               colour="black")+
  geom_segment(x=x+(4.*0.0000151), y=Level, 
               xend=x+(4.*0.0000151), yend=Level+0.000001,
               size=0.3,
               colour="black")+
  geom_segment(x=x+(6.*0.0000151), y=Level, 
               xend=x+(6.*0.0000151), yend=Level+0.000001,
               size=0.3,
               colour="black")+
  geom_segment(x=x+(8.*0.0000151), y=Level, 
               xend=x+(8.*0.0000151), yend=Level+0.000001,
               size=0.3,
               colour="black")+
  geom_segment(x=x+(10.*0.0000151), y=Level, 
               xend=x+(10.*0.0000151), yend=Level+0.000001,
               size=0.3,
               colour="black")+
  geom_segment(x=x+(12.*0.0000151), y=Level, 
               xend=x+(12.*0.0000151), yend=Level+0.000001,
               size=0.3,
               colour="black")+
  
  annotate(geom="text", x = x, y = Level+0.000004, 
           label="0", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = x-(2*0.0000151), y = Level+0.000004, 
           label="-2", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = x+(2*0.0000151), y = Level+0.000004, 
           label="    2", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = x+(4*0.0000151), y = Level+0.000004, 
           label="    4", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = x+(6*0.0000151), y = Level+0.000004, 
           label="    6", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = x+(8*0.0000151), y = Level+0.000004, 
           label="    8", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = x+(10*0.0000151), y = Level+0.000004, 
           label="    10", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = x+(12*0.0000151), y = Level+0.000004, 
           label="    12 m", angle=0,
           colour = "black", cex=5)+
  
  #Vertical scale
  geom_segment(x=Vertical, y=y-(4*0.0000090), 
               xend=Vertical, yend=y+(12*0.0000090),
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y+(12*0.0000090), 
               xend=Vertical+(0.00000168), yend=y+(12*0.0000090),
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y+(10*0.0000090), 
               xend=Vertical+(0.00000168), yend=y+(10*0.0000090),
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y+(8*0.0000090), 
               xend=Vertical+(0.00000168), yend=y+(8*0.0000090),
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y+(6*0.0000090), 
               xend=Vertical+(0.00000168), yend=y+(6*0.0000090),
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y+(4*0.0000090), 
               xend=Vertical+(0.00000168), yend=y+(4*0.0000090),
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y+(2*0.0000090), 
               xend=Vertical+(0.00000168), yend=y+(2*0.0000090),
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y, 
               xend=Vertical+0.00000168, yend=y,
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y-(2*0.0000090), 
               xend=Vertical+(0.00000168), yend=y-(2*0.0000090),
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y-(4*0.0000090), 
               xend=Vertical+(0.00000168), yend=y-(4*0.0000090),
               size=0.3,
               colour="black")+
  
  annotate(geom="text", x = Vertical+0.000006, y = y+(8*0.0000090), 
           label="8", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = Vertical+0.000008, y = y+(10*0.0000090), 
           label="10", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = Vertical+0.00001, y = y+(12*0.0000090), 
           label="12 m", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = Vertical+0.000008, y = y+(6*0.0000090), 
           label="6", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = Vertical+0.000006, y = y+(4*0.0000090), 
           label="4", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = Vertical+0.000006, y = y+(2*0.0000090), 
           label="2", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = Vertical+0.000006, y = y, 
           label="0", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = Vertical+0.000006, y = y-(2*0.0000090), 
           label="-2", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = Vertical+0.000006, y = y-(4*0.0000090), 
           label="-4", angle=0,
           colour = "black", cex=5)

####################################################################


####Walked Transect Survey####

EWSN_T <-read.csv("Walked_Transect_Survey.csv")

#ew Transect
EW_T <-subset(EWSN_T,Transect=="ew")

EW_T.gg <-ggplot(data=EW_T, aes(x=lon, y=lat,colour=Receiver))+
  geom_jitter(pch=8, size=0.8,width=0.0000001,height=0.0000001)+
  theme_bw()+ scale_colour_manual(values=cbbPalette)+
  theme(legend.position="bottom")+
  guides(color=guide_legend(override.aes = list(size=c(2))))+
  xlab("Longitude (degrees)")+ylab("Latitude (degrees)")+
  coord_fixed(ratio=151/90)+
  scale_x_continuous(limits = c(-2.47496,-2.47465),labels = label_number(accuracy = 0.00001))+
  scale_y_continuous(labels = label_number(accuracy = 0.00001))+
  
annotate("segment", x = x, y = y, 
         xend=ew.x, yend=ew.y,
         colour = "red", size = 1)+
  annotate(geom="text", x = -2.474925, y = 53.450915, 
           label="Base Station", angle=0,cex=5,
           colour = "red")+
  annotate(geom="text", x = -2.474668, y = 53.450954, 
           label="Transect Point 
           ew", angle=0,cex=5,
           colour = "red")+
  annotate(geom="point", x = x, y = y , size=2,colour = "red")+
  annotate(geom="point", x = ew.x, y = ew.y , size=2,colour = "red")

EW_T.gg
  
##Add scale bars  
  
Vertical=x-0.000086
Level=y-0.000075

EW_T.gg+
  #Horizontal scale
  geom_segment(x=x-(2*0.0000151), y=Level, 
               xend=x+(14*0.0000151), yend=Level,
               size=0.3,
               colour="black")+
  geom_segment(x=x-(2*0.0000151), y=Level, 
               xend=x-(2*0.0000151), 
               yend=Level+0.000001,
               size=0.3,
               colour="black")+
  geom_segment(x=x, y=Level, 
               xend=x, yend=Level+0.000001,
               size=0.3,
               colour="black")+
  geom_segment(x=x+(2.*0.0000151), y=Level, 
               xend=x+(2.*0.0000151), yend=Level+0.000001,
               size=0.3,
               colour="black")+
  geom_segment(x=x+(4.*0.0000151), y=Level, 
               xend=x+(4.*0.0000151), yend=Level+0.000001,
               size=0.3,
               colour="black")+
  geom_segment(x=x+(6.*0.0000151), y=Level, 
               xend=x+(6.*0.0000151), yend=Level+0.000001,
               size=0.3,
               colour="black")+
  geom_segment(x=x+(8.*0.0000151), y=Level, 
               xend=x+(8.*0.0000151), yend=Level+0.000001,
               size=0.3,
               colour="black")+
  geom_segment(x=x+(10.*0.0000151), y=Level, 
               xend=x+(10.*0.0000151), yend=Level+0.000001,
               size=0.3,
               colour="black")+
  geom_segment(x=x+(12.*0.0000151), y=Level, 
               xend=x+(12.*0.0000151), yend=Level+0.000001,
               size=0.3,
               colour="black")+
  geom_segment(x=x+(14.*0.0000151), y=Level, 
               xend=x+(14.*0.0000151), yend=Level+0.000001,
               size=0.3,
               colour="black")+
  
  annotate(geom="text", x = x, y = Level+0.000004, 
           label="0", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = x-(2*0.0000151), y = Level+0.000004, 
           label="-2", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = x+(2*0.0000151), y = Level+0.000004, 
           label="    2", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = x+(4*0.0000151), y = Level+0.000004, 
           label="    4", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = x+(6*0.0000151), y = Level+0.000004, 
           label="    6", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = x+(8*0.0000151), y = Level+0.000004, 
           label="    8", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = x+(10*0.0000151), y = Level+0.000004, 
           label="    10", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = x+(12*0.0000151), y = Level+0.000004, 
           label="    12", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = x+(14*0.0000151), y = Level+0.000004, 
           label="    14 m", angle=0,
           colour = "black", cex=5)+
  
  #Vertical scale
  geom_segment(x=Vertical, y=y-(8*0.0000090), 
               xend=Vertical, yend=y+(12*0.0000090),
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y+(12*0.0000090), 
               xend=Vertical+(0.00000168), yend=y+(12*0.0000090),
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y+(10*0.0000090), 
               xend=Vertical+(0.00000168), yend=y+(10*0.0000090),
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y+(8*0.0000090), 
               xend=Vertical+(0.00000168), yend=y+(8*0.0000090),
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y+(6*0.0000090), 
               xend=Vertical+(0.00000168), yend=y+(6*0.0000090),
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y+(4*0.0000090), 
               xend=Vertical+(0.00000168), yend=y+(4*0.0000090),
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y+(2*0.0000090), 
               xend=Vertical+(0.00000168), yend=y+(2*0.0000090),
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y, 
               xend=Vertical+0.00000168, yend=y,
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y-(2*0.0000090), 
               xend=Vertical+(0.00000168), yend=y-(2*0.0000090),
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y-(4*0.0000090), 
               xend=Vertical+(0.00000168), yend=y-(4*0.0000090),
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y-(6*0.0000090), 
               xend=Vertical+(0.00000168), yend=y-(6*0.0000090),
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y-(8*0.0000090), 
               xend=Vertical+(0.00000168), yend=y-(8*0.0000090),
               size=0.3,
               colour="black")+
 
  annotate(geom="text", x = Vertical+0.000012, y = y+(12*0.0000090), 
           label="12 m", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = Vertical+0.000008, y = y+(10*0.0000090), 
           label="10", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = Vertical+0.000008, y = y+(8*0.0000090), 
           label="8", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = Vertical+0.000008, y = y+(6*0.0000090), 
           label="6", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = Vertical+0.000008, y = y+(4*0.0000090), 
           label="4", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = Vertical+0.000008, y = y+(2*0.0000090), 
           label="2", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = Vertical+0.000008, y = y, 
           label="0", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = Vertical+0.000006, y = y-(2*0.0000090), 
           label="-2", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = Vertical+0.000006, y = y-(4*0.0000090), 
           label="-4", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = Vertical+0.000006, y = y-(6*0.0000090), 
           label="-6", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = Vertical+0.000006, y = y-(8*0.0000090), 
           label="-8", angle=0,
           colour = "black", cex=5)
 


print(EW_T.gg, width=unit(1510/2,"points"), height=unit(900/2,"points"))

#sn Transect
SN_T <-subset(EWSN_T,Transect=="sn")

SN_T.gg <-ggplot(data=SN_T, aes(x=lon, y=lat,colour=Receiver))+
  geom_jitter(pch=8, size=0.8,width=0.0000001,height=0.0000001)+
  theme_bw()+ scale_colour_manual(values=cbbPalette)+
  theme(legend.position=c(.8,.9))+
  guides(color=guide_legend(override.aes = list(size=c(2))))+
  xlab("Longitude (degrees)")+ylab("Latitude (degrees)")+
  coord_fixed(ratio=151/90)+
  scale_x_continuous(limits = c(-2.47495,-2.47470),labels = label_number(accuracy = 0.00001))+
  scale_y_continuous(labels = label_number(accuracy = 0.00001))+
  annotate("segment", x = x, y = y, 
           xend=sn.x, yend=sn.y,
           colour = "red", size = 1)+
  annotate(geom="text", x = -2.474925, y = 53.450917, 
           label="Base 
           Station", angle=0,cex=5,
           colour = "red")+
  annotate(geom="text", x = -2.474860, y = 53.450807, 
           label="Transect Point sn", angle=0,cex=5,
           colour = "red")+
  annotate(geom="point", x = x, y = y , size=2,colour = "red")+
  annotate(geom="point", x = sn.x, y = sn.y , size=2,colour = "red")
 
SN_T.gg 
 
 ##Add scale bars  
 
 Vertical=x-0.00006
 Level=y-0.00012
 
 SN_T.gg+
   #Horizontal scale
   geom_segment(x=x-(2*0.0000151), y=Level, 
                xend=x+(10*0.0000151), yend=Level,
                size=0.3,
                colour="black")+
   geom_segment(x=x-(2*0.0000151), y=Level, 
                xend=x-(2*0.0000151), 
                yend=Level+0.000001,
                size=0.3,
                colour="black")+
   geom_segment(x=x, y=Level, 
                xend=x, yend=Level+0.000001,
                size=0.3,
                colour="black")+
   geom_segment(x=x+(2.*0.0000151), y=Level, 
                xend=x+(2.*0.0000151), yend=Level+0.000001,
                size=0.3,
                colour="black")+
   geom_segment(x=x+(4.*0.0000151), y=Level, 
                xend=x+(4.*0.0000151), yend=Level+0.000001,
                size=0.3,
                colour="black")+
   geom_segment(x=x+(6.*0.0000151), y=Level, 
                xend=x+(6.*0.0000151), yend=Level+0.000001,
                size=0.3,
                colour="black")+
   geom_segment(x=x+(8.*0.0000151), y=Level, 
                xend=x+(8.*0.0000151), yend=Level+0.000001,
                size=0.3,
                colour="black")+
   geom_segment(x=x+(10.*0.0000151), y=Level, 
                xend=x+(10.*0.0000151), yend=Level+0.000001,
                size=0.3,
                colour="black")+
   
   annotate(geom="text", x = x, y = Level+0.000004, 
            label="0", angle=0,
            colour = "black", cex=5)+
   annotate(geom="text", x = x-(2*0.0000151), y = Level+0.000004, 
            label="-2", angle=0,
            colour = "black", cex=5)+
   annotate(geom="text", x = x+(2*0.0000151), y = Level+0.000004, 
            label="    2", angle=0,
            colour = "black", cex=5)+
   annotate(geom="text", x = x+(4*0.0000151), y = Level+0.000004, 
            label="    4", angle=0,
            colour = "black", cex=5)+
   annotate(geom="text", x = x+(6*0.0000151), y = Level+0.000004, 
            label="    6", angle=0,
            colour = "black", cex=5)+
   annotate(geom="text", x = x+(8*0.0000151), y = Level+0.000004, 
            label="    8", angle=0,
            colour = "black", cex=5)+
   annotate(geom="text", x = x+(10*0.0000151), y = Level+0.000004, 
            label="    10 m", angle=0,
            colour = "black", cex=5)+
   
   #Vertical scale
   geom_segment(x=Vertical, y=y-(12*0.0000090), 
                xend=Vertical, yend=y+(10*0.0000090),
                size=0.35,
                colour="black")+
   geom_segment(x=Vertical, y=y+(8*0.0000090), 
                xend=Vertical+(0.00000168), yend=y+(8*0.0000090),
                size=0.3,
                colour="black")+
   geom_segment(x=Vertical, y=y+(10*0.0000090), 
                xend=Vertical+(0.00000168), yend=y+(10*0.0000090),
                size=0.3,
                colour="black")+
   geom_segment(x=Vertical, y=y+(6*0.0000090), 
                xend=Vertical+(0.00000168), yend=y+(6*0.0000090),
                size=0.3,
                colour="black")+
   geom_segment(x=Vertical, y=y+(4*0.0000090), 
                xend=Vertical+(0.00000168), yend=y+(4*0.0000090),
                size=0.3,
                colour="black")+
   geom_segment(x=Vertical, y=y+(2*0.0000090), 
                xend=Vertical+(0.00000168), yend=y+(2*0.0000090),
                size=0.3,
                colour="black")+
   geom_segment(x=Vertical, y=y, 
                xend=Vertical+0.00000168, yend=y,
                size=0.3,
                colour="black")+
   geom_segment(x=Vertical, y=y-(2*0.0000090), 
                xend=Vertical+(0.00000168), yend=y-(2*0.0000090),
                size=0.3,
                colour="black")+
   geom_segment(x=Vertical, y=y-(4*0.0000090), 
                xend=Vertical+(0.00000168), yend=y-(4*0.0000090),
                size=0.3,
                colour="black")+
   geom_segment(x=Vertical, y=y-(6*0.0000090), 
                xend=Vertical+(0.00000168), yend=y-(6*0.0000090),
                size=0.3,
                colour="black")+
   geom_segment(x=Vertical, y=y-(8*0.0000090), 
                xend=Vertical+(0.00000168), yend=y-(8*0.0000090),
                size=0.3,
                colour="black")+
   geom_segment(x=Vertical, y=y-(10*0.0000090), 
                xend=Vertical+(0.00000168), yend=y-(10*0.0000090),
                size=0.3,
                colour="black")+
   geom_segment(x=Vertical, y=y-(12*0.0000090), 
                xend=Vertical+(0.00000168), yend=y-(12*0.0000090),
                size=0.3,
                colour="black")+
   
   annotate(geom="text", x = Vertical+0.000012, y = y+(10*0.0000090), 
            label="10 m", angle=0,
            colour = "black", cex=5)+
   annotate(geom="text", x = Vertical+0.000006, y = y+(8*0.0000090), 
            label="8", angle=0,
            colour = "black", cex=5)+
   annotate(geom="text", x = Vertical+0.000006, y = y+(6*0.0000090), 
            label="6", angle=0,
            colour = "black", cex=5)+
   annotate(geom="text", x = Vertical+0.000006, y = y+(4*0.0000090), 
            label="4", angle=0,
            colour = "black", cex=5)+
   annotate(geom="text", x = Vertical+0.000006, y = y+(2*0.0000090), 
            label="2", angle=0,
            colour = "black", cex=5)+
   annotate(geom="text", x = Vertical+0.000006, y = y, 
            label="0", angle=0,
            colour = "black", cex=5)+
   annotate(geom="text", x = Vertical+0.000006, y = y-(2*0.0000090), 
            label="-2", angle=0,
            colour = "black", cex=5)+
   annotate(geom="text", x = Vertical+0.000006, y = y-(4*0.0000090), 
            label="-4", angle=0,
            colour = "black", cex=5)+
   annotate(geom="text", x = Vertical+0.000006, y = y-(6*0.0000090), 
            label="-6", angle=0,
            colour = "black", cex=5)+
   annotate(geom="text", x = Vertical+0.000006, y = y-(8*0.0000090), 
            label="-8", angle=0,
            colour = "black", cex=5)+
   annotate(geom="text", x = Vertical+0.000008, y = y-(10*0.0000090), 
            label="-10", angle=0,
            colour = "black", cex=5)+
   annotate(geom="text", x = Vertical+0.000008, y = y-(12*0.0000090), 
            label="-12", angle=0,
            colour = "black", cex=5)
 
print(SN_T.gg, width=unit(1510/2,"points"), height=unit(900/2,"points"))
  
#BES EW Figure
BES_EW_T <-subset(EW_T,Receiver=="BES")
BES_EW_T.gg <-ggplot(data=BES_EW_T, aes(x=lon, y=lat))+
  geom_jitter(pch=8, size=0.5,width=0.0000001,height=0.0000001)+
  theme_bw()+ 
  xlab("Longitude (degrees)")+ylab("Latitude (degrees)")+
  coord_fixed(ratio=151/90)+
  scale_x_continuous(limits = c(-2.47492,-2.47468))+
  annotate("segment", x = x, y = y, 
           xend=ew.x, yend=ew.y,
           colour = "red", size = 1)+
  annotate(geom="text", x = -2.474905, y = 53.450912, 
           label="Base Station", angle=0,
           colour = "red")+
  annotate(geom="text", x = -2.47470, y = 53.450954, 
           label="Transect Point 
           ew", angle=0,
           colour = "red")+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.375)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.03,colour="red")+
  annotate(geom="text", x = -2.474905, y = y-0.000010 , 
           label="2 m radius", angle=0,
           colour = "red")
BES_EW_T.gg

BES_SN_T <-subset(SN_T,Receiver=="BES")
BES_SN_T.gg <-ggplot(data=BES_SN_T, aes(x=lon, y=lat))+
  geom_jitter(pch=8, size=0.5,width=0.0000001,height=0.0000001)+
  theme_bw()+ 
  xlab("Longitude (degrees)")+ylab("Latitude (degrees)")+
  coord_fixed(ratio=151/90)+
  scale_x_continuous(limits = c(-2.47493,-2.47480))+
  annotate("segment", x = x, y = y, 
           xend=sn.x, yend=sn.y,
           colour = "red", size = 1)+
  annotate(geom="text", x = -2.474910, y = 53.450912, 
           label="Base Station", angle=0,
           colour = "red")+
  annotate(geom="text", x = -2.474840, y = 53.450805, 
           label="Transect Point sn", angle=0,
           colour = "red")+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.375)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.03,colour="red")+
  annotate(geom="text", x = x-0.000024, y = y-0.000011 , 
           label="2 m radius", angle=0,
           colour = "red")
 
BES_SN_T.gg

######################################
#BES Dual Transect Figure

BES_T <-subset(EWSN_T,Receiver=="BES")

BES_T.gg <-ggplot(data=BES_T, aes(x=lon, y=lat))+
  geom_jitter(pch=8, size=0.5,width=0.0000001,height=0.0000001)+
  theme_bw()+ 
  xlab("Longitude (degrees)")+ylab("Latitude (degrees)")+
  coord_fixed(ratio=151/90)+
  scale_x_continuous(limits = c(-2.47495,-2.47468),labels = label_number(accuracy = 0.00001))+
  scale_y_continuous(limits = c(y-(14*0.0000090), y+(7*0.0000090)),labels = label_number(accuracy = 0.00001))+
  annotate("segment", x = x, y = y, 
           xend=sn.x, yend=sn.y,
           colour = "red", size = 1)+
  annotate(geom="text", x = -2.474918, y = 53.450907, 
           label="Base Station", angle=0,cex=5,
           colour = "red")+
  annotate(geom="text", x = -2.474760, y = 53.450809, 
           label="Transect Point sn", angle=0,cex=5,
           colour = "red")+
  annotate(geom="point",x=x,y=y,size=2, colour="red")+
  annotate(geom="point",x=sn.x,y=sn.y,size=2, colour="red")+
  annotate(geom="point",x=ew.x,y=ew.y,size=2, colour="red")+
  annotate("segment", x = x, y = y, 
           xend=ew.x, yend=ew.y,
           colour = "red", size = 1)+
  annotate(geom="text", x = -2.47472, y = 53.450945, 
           label="Transect Point 
           ew", angle=0, cex=5,
           colour = "red")


##Add scale bars  

Vertical=x-0.000068
Level=y-0.000128

BES_T.gg+
  #Horizontal scale
  geom_segment(x=x-(2*0.0000151), y=Level, 
               xend=x+(12*0.0000151), yend=Level,
               size=0.3,
               colour="black")+
  geom_segment(x=x-(2*0.0000151), y=Level, 
               xend=x-(2*0.0000151), 
               yend=Level+0.000001,
               size=0.3,
               colour="black")+
  geom_segment(x=x, y=Level, 
               xend=x, yend=Level+0.000001,
               size=0.3,
               colour="black")+
  geom_segment(x=x+(2.*0.0000151), y=Level, 
               xend=x+(2.*0.0000151), yend=Level+0.000001,
               size=0.3,
               colour="black")+
  geom_segment(x=x+(4.*0.0000151), y=Level, 
               xend=x+(4.*0.0000151), yend=Level+0.000001,
               size=0.3,
               colour="black")+
  geom_segment(x=x+(6.*0.0000151), y=Level, 
               xend=x+(6.*0.0000151), yend=Level+0.000001,
               size=0.3,
               colour="black")+
  geom_segment(x=x+(8.*0.0000151), y=Level, 
               xend=x+(8.*0.0000151), yend=Level+0.000001,
               size=0.3,
               colour="black")+
  geom_segment(x=x+(10.*0.0000151), y=Level, 
               xend=x+(10.*0.0000151), yend=Level+0.000001,
               size=0.3,
               colour="black")+
  geom_segment(x=x+(12.*0.0000151), y=Level, 
               xend=x+(12.*0.0000151), yend=Level+0.000001,
               size=0.3,
               colour="black")+

  annotate(geom="text", x = x, y = Level+0.000004, 
           label="0", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = x-(2*0.0000151), y = Level+0.000004, 
           label="-2", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = x+(2*0.0000151), y = Level+0.000004, 
           label="    2", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = x+(4*0.0000151), y = Level+0.000004, 
           label="    4", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = x+(6*0.0000151), y = Level+0.000004, 
           label="    6", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = x+(8*0.0000151), y = Level+0.000004, 
           label="    8", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = x+(10*0.0000151), y = Level+0.000004, 
           label="    10", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = x+(12*0.0000151), y = Level+0.000004, 
           label="    12 m", angle=0,
           colour = "black", cex=5)+
  
  #Vertical scale
  geom_segment(x=Vertical, y=y-(12*0.0000090), 
               xend=Vertical, yend=y+(6*0.0000090),
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y+(6*0.0000090), 
               xend=Vertical+(0.00000168), yend=y+(6*0.0000090),
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y+(4*0.0000090), 
               xend=Vertical+(0.00000168), yend=y+(4*0.0000090),
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y+(2*0.0000090), 
               xend=Vertical+(0.00000168), yend=y+(2*0.0000090),
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y, 
               xend=Vertical+0.00000168, yend=y,
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y-(2*0.0000090), 
               xend=Vertical+(0.00000168), yend=y-(2*0.0000090),
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y-(4*0.0000090), 
               xend=Vertical+(0.00000168), yend=y-(4*0.0000090),
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y-(6*0.0000090), 
               xend=Vertical+(0.00000168), yend=y-(6*0.0000090),
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y-(8*0.0000090), 
               xend=Vertical+(0.00000168), yend=y-(8*0.0000090),
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y-(10*0.0000090), 
               xend=Vertical+(0.00000168), yend=y-(10*0.0000090),
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y-(12*0.0000090), 
               xend=Vertical+(0.00000168), yend=y-(12*0.0000090),
               size=0.3,
               colour="black")+

  annotate(geom="text", x = Vertical+0.00001, y = y+(6*0.0000090), 
           label="6 m", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = Vertical+0.000006, y = y+(4*0.0000090), 
           label="4", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = Vertical+0.000006, y = y+(2*0.0000090), 
           label="2", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = Vertical+0.000006, y = y, 
           label="0", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = Vertical+0.000006, y = y-(2*0.0000090), 
           label="-2", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = Vertical+0.000006, y = y-(4*0.0000090), 
           label="-4", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = Vertical+0.000006, y = y-(6*0.0000090), 
           label="-6", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = Vertical+0.000006, y = y-(8*0.0000090), 
           label="-8", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = Vertical+0.000008, y = y-(10*0.0000090), 
           label="-10", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = Vertical+0.000008, y = y-(12*0.0000090), 
           label="-12", angle=0,
           colour = "black", cex=5)


###################################################

####Roaming Point Survey####
EWSN_R <-read.csv("Roaming_Point_Survey.csv")

EWSN_R.gg <-
  ggplot(data=EWSN_R, aes(x=lon, y=lat,colour=Receiver))+ 
  geom_jitter(pch=8, size=0.5, width=0.0000015,height=0.0000015)+
  theme_bw()+ scale_colour_manual(values=cbbPalette)+
  guides(color=guide_legend(override.aes = list(size=c(2))))+
  coord_fixed(ratio=151/90)+
  xlab("Longitude (degrees)")+ylab("Latitude (degrees)")+
  annotate("pointrange", x = x, y = y, 
           ymin = ymin , ymax = ymax,
           colour = "red", size = 0.375)+
  geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.01,colour="red")+
  annotate(geom="text", x = x-0.00005, y = y-0.000003, 
           label="Base Station", angle=0,
           colour = "red")+
  annotate("path", colour = "red", size=0.375,
           x=x+2*0.0000151*cos(seq(0,2*pi,length.out=100)),
           y=y+2*0.0000090*sin(seq(0,2*pi,length.out=100)))+
  annotate("path", colour = "red", size=0.375,
           x=x+0.0000151*cos(seq(0,2*pi,length.out=100)),
           y=y+0.0000090*sin(seq(0,2*pi,length.out=100)))+
  annotate(geom="text", x = x+0.000008, y = y-0.000011, 
           label="1 m", angle=0,cex=5,
           colour = "white")+
  annotate(geom="text", x = x+0.000003, y = y-0.000022 , 
           label="2 m", angle=0,cex=5,
           colour = "red")+ 
  scale_y_continuous(labels = label_number(accuracy = 0.00001))+
  scale_x_continuous(labels = label_number(accuracy = 0.00001))
                    
  #Add Scale Bars 
  Vertical = x-0.00028
  Level = y-0.00012

EWSN_R.gg+
  #Horizontal scale
  geom_segment(x=x-(16*0.0000151), y=Level, 
               xend=x+(10*0.0000151), yend=Level,
               size=0.3,
               colour="black")+
  geom_segment(x=x-(4.*0.0000151), y=Level, 
               xend=x-(4.*0.0000151), yend=Level+0.000001,
               size=0.3,
               colour="black")+
  geom_segment(x=x-(6.*0.0000151), y=Level, 
               xend=x-(6.*0.0000151), yend=Level+0.000001,
               size=0.3,
               colour="black")+
  geom_segment(x=x-(8.*0.0000151), y=Level, 
               xend=x-(8.*0.0000151), yend=Level+0.000001,
               size=0.3,
               colour="black")+
  geom_segment(x=x-(10.*0.0000151), y=Level, 
               xend=x-(10.*0.0000151), yend=Level+0.000001,
               size=0.3,
               colour="black")+
  geom_segment(x=x-(12.*0.0000151), y=Level, 
               xend=x-(12.*0.0000151), yend=Level+0.000001,
               size=0.3,
               colour="black")+
  geom_segment(x=x-(14.*0.0000151), y=Level, 
               xend=x-(14.*0.0000151), yend=Level+0.000001,
               size=0.3,
               colour="black")+
  geom_segment(x=x-(16.*0.0000151), y=Level, 
               xend=x-(16.*0.0000151), yend=Level+0.000001,
               size=0.3,
               colour="black")+
  geom_segment(x=x-(2*0.0000151), y=Level, 
               xend=x-(2*0.0000151), 
               yend=Level+0.000001,
               size=0.3,
               colour="black")+
  geom_segment(x=x, y=Level, 
               xend=x, yend=Level+0.000001,
               size=0.3,
               colour="black")+
  geom_segment(x=x+(2.*0.0000151), y=Level, 
               xend=x+(2.*0.0000151), yend=Level+0.000001,
               size=0.3,
               colour="black")+
  geom_segment(x=x+(4.*0.0000151), y=Level, 
               xend=x+(4.*0.0000151), yend=Level+0.000001,
               size=0.3,
               colour="black")+
  geom_segment(x=x+(6.*0.0000151), y=Level, 
               xend=x+(6.*0.0000151), yend=Level+0.000001,
               size=0.3,
               colour="black")+
  geom_segment(x=x+(8.*0.0000151), y=Level, 
               xend=x+(8.*0.0000151), yend=Level+0.000001,
               size=0.3,
               colour="black")+
  geom_segment(x=x+(10.*0.0000151), y=Level, 
               xend=x+(10.*0.0000151), yend=Level+0.000001,
               size=0.3,
               colour="black")+
  
  annotate(geom="text", x = x, y = Level+0.000004, 
           label="0", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = x-(16*0.0000151), y = Level+0.000004, 
           label="    -16", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = x-(14*0.0000151), y = Level+0.000004, 
           label="    -14", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = x-(12*0.0000151), y = Level+0.000004, 
           label="    -12", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = x-(10*0.0000151), y = Level+0.000004, 
           label="    -10", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = x-(8*0.0000151), y = Level+0.000004, 
           label="    -8", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = x-(6*0.0000151), y = Level+0.000004, 
           label="    -6", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = x-(4*0.0000151), y = Level+0.000004, 
           label="    -4", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = x-(2*0.0000151), y = Level+0.000004, 
           label="-2", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = x+(2*0.0000151), y = Level+0.000004, 
           label="    2", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = x+(4*0.0000151), y = Level+0.000004, 
           label="    4", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = x+(6*0.0000151), y = Level+0.000004, 
           label="    6", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = x+(8*0.0000151), y = Level+0.000004, 
           label="    8", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = x+(10*0.0000151), y = Level+0.000004, 
           label="    10 m", angle=0,
           colour = "black", cex=5)+

  
  #Vertical scale
  geom_segment(x=Vertical, y=y-(10*0.0000090), 
               xend=Vertical, yend=y+(14*0.0000090),
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y+(14*0.0000090), 
               xend=Vertical+(0.00000168), yend=y+(14*0.0000090),
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y+(12*0.0000090), 
               xend=Vertical+(0.00000168), yend=y+(12*0.0000090),
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y+(10*0.0000090), 
               xend=Vertical+(0.00000168), yend=y+(10*0.0000090),
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y+(8*0.0000090), 
               xend=Vertical+(0.00000168), yend=y+(8*0.0000090),
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y+(6*0.0000090), 
               xend=Vertical+(0.00000168), yend=y+(6*0.0000090),
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y+(4*0.0000090), 
               xend=Vertical+(0.00000168), yend=y+(4*0.0000090),
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y+(2*0.0000090), 
               xend=Vertical+(0.00000168), yend=y+(2*0.0000090),
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y, 
               xend=Vertical+0.00000168, yend=y,
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y-(2*0.0000090), 
               xend=Vertical+(0.00000168), yend=y-(2*0.0000090),
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y-(4*0.0000090), 
               xend=Vertical+(0.00000168), yend=y-(4*0.0000090),
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y-(6*0.0000090), 
               xend=Vertical+(0.00000168), yend=y-(6*0.0000090),
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y-(8*0.0000090), 
               xend=Vertical+(0.00000168), yend=y-(8*0.0000090),
               size=0.3,
               colour="black")+
  geom_segment(x=Vertical, y=y-(10*0.0000090), 
               xend=Vertical+(0.00000168), yend=y-(10*0.0000090),
               size=0.3,
               colour="black")+
  
  annotate(geom="text", x = Vertical+0.000016, y = y+(14*0.0000090), 
           label="14 m", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = Vertical+0.00001, y = y+(12*0.0000090), 
           label="12", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = Vertical+0.00001, y = y+(10*0.0000090), 
           label="10", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = Vertical+0.000008, y = y+(8*0.0000090), 
           label="8", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = Vertical+0.000008, y = y+(6*0.0000090), 
           label="6", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = Vertical+0.000008, y = y+(4*0.0000090), 
           label="4", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = Vertical+0.000008, y = y+(2*0.0000090), 
           label="2", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = Vertical+0.00001, y = y, 
           label="0", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = Vertical+0.00001, y = y-(2*0.0000090), 
           label="-2", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = Vertical+0.00001, y = y-(4*0.0000090), 
           label="-4", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = Vertical+0.00001, y = y-(6*0.0000090), 
           label="-6", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = Vertical+0.00001, y = y-(8*0.0000090), 
           label="-8", angle=0,
           colour = "black", cex=5)+
  annotate(geom="text", x = Vertical+0.000012, y = y-(10*0.0000090), 
           label="-10", angle=0,
           colour = "black", cex=5)

  print(EWSN_R.gg, width=unit(15.1/2.1,"cm"), height=unit(9/2.1,"cm"))
 
##BES Roaming Point Figure
    BES_R <-subset(EWSN_R,Receiver=="BES")
  BES_R.gg <-ggplot(data=BES_R, aes(x=lon, y=lat))+ theme_bw()+
    geom_jitter(pch=8, size=0.5,width=0.0000005,height=0.0000005)+ 
    coord_fixed(ratio=151/90)+
    scale_x_continuous(limits = c(-2.47492,-2.474800),labels = label_number(accuracy = 0.00001))+ 
    scale_y_continuous(labels = label_number(accuracy = 0.00001))+
    xlab("Longitude (degrees)")+ylab("Latitude (degrees)")+
    annotate("pointrange", x = x, y = y, 
             ymin = ymin , ymax = ymax,
             colour = "red", size = 0.375)+
    geom_segment(x=xmin, y=y, xend=xmax, yend=y,size=0.03,colour="red")+
    annotate(geom="text", x = x-0.000010, y = y-0.000001, 
             label="Base Station", angle=0,cex=5,
             colour = "red")+
    annotate("path", colour = "red", size=0.375,
             x=x+2*0.0000151*cos(seq(0,2*pi,length.out=100)),
             y=y+2*0.0000090*sin(seq(0,2*pi,length.out=100)))+
    annotate("path", colour = "red", size=0.375,
             x=x+0.0000151*cos(seq(0,2*pi,length.out=100)),
             y=y+0.0000090*sin(seq(0,2*pi,length.out=100)))+
    annotate(geom="text", x = x+0.000003, y = y-0.000010, 
             label="1 m", angle=0,cex=5,
             colour = "red")+
    annotate(geom="text", x = x+0.000003, y = y-0.000019 , 
             label="2 m", angle=0, cex=5,
             colour = "red")


  Vertical=x-0.000044
  Level=y-0.000026
  
  BES_R.gg+
    #Horizontal scale
    geom_segment(x=x-(2*0.0000151), y=Level, 
                 xend=x+(5*0.0000151), yend=Level,
                 size=0.3,
                 colour="black")+
    geom_segment(x=x-(2*0.0000151), y=Level, 
                 xend=x-(2*0.0000151), yend=Level+0.000001,
                 size=0.3,
                 colour="black")+
    geom_segment(x=x-(1*0.0000151), y=Level, 
                 xend=x-(1*0.0000151), yend=Level+0.0000005,
                 size=0.3,
                 colour="black")+
    geom_segment(x=x, y=Level, 
                 xend=x, yend=Level+0.000001,
                 size=0.3,
                 colour="black")+
    geom_segment(x=x+(1.*0.0000151), y=Level, 
                 xend=x+(1.*0.0000151), yend=Level+0.0000005,
                 size=0.3,
                 colour="black")+
    geom_segment(x=x+(2.*0.0000151), y=Level, 
                 xend=x+(2.*0.0000151), yend=Level+0.000001,
                 size=0.3,
                 colour="black")+
    geom_segment(x=x+(3.*0.0000151), y=Level, 
                 xend=x+(3.*0.0000151), yend=Level+0.000001,
                 size=0.3,
                 colour="black")+
    geom_segment(x=x+(4.*0.0000151), y=Level, 
                 xend=x+(4.*0.0000151), yend=Level+0.000001,
                 size=0.3,
                 colour="black")+
    geom_segment(x=x+(5.*0.0000151), y=Level, 
                 xend=x+(5.*0.0000151), yend=Level+0.000001,
                 size=0.3,
                 colour="black")+
    annotate(geom="text", x = x, y = Level+0.000002, 
             label="0", angle=0,
             colour = "black", cex=5)+
    annotate(geom="text", x = x-(2*0.0000151), y = Level+0.000002, 
             label="-2", angle=0,
             colour = "black", cex=5)+
    annotate(geom="text", x = x-(1*0.0000151), y = Level+0.000002, 
             label="-1", angle=0,
             colour = "black", cex=5)+
    annotate(geom="text", x = x+(1*0.0000151), y = Level+0.000002, 
             label="1", angle=0,
             colour = "black", cex=5)+
    annotate(geom="text", x = x+(2*0.0000151), y = Level+0.000002, 
             label="    2", angle=0,
             colour = "black", cex=5)+
    annotate(geom="text", x = x+(3*0.0000151), y = Level+0.000002, 
             label="    3", angle=0,
             colour = "black", cex=5)+
    annotate(geom="text", x = x+(4*0.0000151), y = Level+0.000002, 
             label="    4", angle=0,
             colour = "black", cex=5)+
    annotate(geom="text", x = x+(5*0.0000151), y = Level+0.000002, 
             label="    5 m", angle=0,
             colour = "black", cex=5)+
    
    #Vertical scale
    geom_segment(x=Vertical, y=y-(2*0.0000090), 
                 xend=Vertical, yend=y+(4*0.0000090),
                 size=0.3,
                 colour="black")+
    geom_segment(x=Vertical, y=y, 
                 xend=Vertical+0.00000168, yend=y,
                 size=0.3,
                 colour="black")+
    geom_segment(x=Vertical, y=y-(2*0.0000090), 
                 xend=Vertical+0.00000168, yend=y-(2*0.0000090),
                 size=0.3,
                 colour="black")+
    geom_segment(x=Vertical, y=y-(1*0.0000090), 
                 xend=Vertical+(0.00000168/2), yend=y-(1*0.0000090),
                 size=0.3,
                 colour="black")+
    geom_segment(x=Vertical, y=y+(1*0.0000090), 
                 xend=Vertical+(0.00000168/2), yend=y+(1*0.0000090),
                 size=0.3,
                 colour="black")+
    geom_segment(x=Vertical, y=y+(2*0.0000090), 
                 xend=Vertical+(0.00000168/2), yend=y+(2*0.0000090),
                 size=0.3,
                 colour="black")+
    geom_segment(x=Vertical, y=y+(3*0.0000090), 
                 xend=Vertical+(0.00000168), yend=y+(3*0.0000090),
                 size=0.3,
                 colour="black")+
    geom_segment(x=Vertical, y=y+(4*0.0000090), 
                 xend=Vertical+(0.00000168), yend=y+(4*0.0000090),
                 size=0.3,
                 colour="black")+
    annotate(geom="text", x = Vertical+0.00000336, y = y, 
             label="0", angle=0,
             colour = "black", cex=5)+
    annotate(geom="text", x = Vertical+0.00000336, y = y-(1*0.0000090), 
             label="-1", angle=0,
             colour = "black", cex=5)+
    annotate(geom="text", x = Vertical+0.00000336, y = y-(2*0.0000090), 
             label="-2", angle=0,
             colour = "black", cex=5)+
    annotate(geom="text", x = Vertical+0.00000336, y = y+(1*0.0000090), 
             label="1", angle=0,
             colour = "black", cex=5)+
    annotate(geom="text", x = Vertical+0.00000336, y = y+(2*0.0000090), 
             label="2", angle=0,
             colour = "black", cex=5)+
    annotate(geom="text", x = Vertical+0.00000336, y = y+(3*0.0000090), 
             label="    3", angle=0,
             colour = "black", cex=5)+
    annotate(geom="text", x = Vertical+0.00000336, y = y+(4*0.0000090), 
             label="    4 m", angle=0,
             colour = "black", cex=5)
  
  

#####################
####Density Plots####
#####################
  
  EWSN_F[which.max(EWSN_F$Dist),]
  EWSN_F.d.gg <-ggplot(EWSN_F, aes(x=Dist,colour=Receiver,fill=Receiver))+ 
    xlab("Fixed Base Station Survey: Distance (m)")+ylab("density")+
    geom_density(alpha=.4, size=1.,bw=.1)+
    #coord_fixed(ratio=5)+ 
    xlim(0,20)+
    theme_bw()+ scale_colour_manual(values=cbbPalette)+scale_fill_manual(values=cbbPalette)+
    geom_segment(x=1, y=0.0, xend=1, yend=1.5,size=0.05,colour="black",linetype=2)+
    annotate(geom="text", x = .5, y = 1.475, 
             label="1 m", angle=0,
             colour = "black")+
    geom_segment(x=2, y=0., xend=2, yend=1.5 ,size=0.05,colour="black",linetype=2)+
    annotate(geom="text", x = 2.5, y = 1.475, 
             label="2 m", angle=0,
             colour = "black")+
    geom_segment(x=14.44, y=0., xend=14.44, yend=0.1 ,size=0.05,colour="black",linetype=2)+
    annotate(geom="text", x = 14.44, y = 0.15, 
             label="Max; iP12 = 14.44 m", angle=0,
             colour = "black")
  EWSN_F.d.gg   
  
EWSN_T[which.max(EWSN_T$d),]
EWSN_T.d.gg <-ggplot(EWSN_T, aes(x=d,colour=Receiver,fill=Receiver))+ 
  xlab("Walked Transect Survey: Distance (m)")+ylab("density")+
  geom_density(alpha=.4, size=1.,bw=.1)+
  #geom_histogram(binwidth=.1)+
  #coord_fixed(ratio=5)+ 
  xlim(0,20)+
  theme_bw()+ scale_colour_manual(values=cbbPalette)+scale_fill_manual(values=cbbPalette)+
  geom_segment(x=1, y=0.0, xend=1, yend=1,size=0.05,colour="black",linetype=2)+
  annotate(geom="text", x = 1.5, y = .95, 
           label="1 m", angle=0,
           colour = "black")+
  geom_segment(x=2, y=0., xend=2, yend=1 ,size=0.05,colour="black",linetype=2)+
  annotate(geom="text", x = 2.5, y = .95, 
           label="2 m", angle=0,
           colour = "black")+
  geom_segment(x=11.68, y=0., xend=11.68, yend=0.1 ,size=0.05,colour="black",linetype=2)+
  annotate(geom="text", x = 11.68, y = 0.15, 
           label="Max; iP6 = 11.68 m", angle=0,
           colour = "black")
EWSN_T.d.gg

EWSN_R[which.max(EWSN_R$Dist),]
EWSN_R.d.gg <-ggplot(EWSN_R, aes(x=Dist,colour=Receiver,fill=Receiver))+ 
  xlab("Roaming Point Survey: Distance (m)")+ylab("density")+
  geom_density(alpha=.4, size=1.,bw=0.1)+
  #coord_fixed(ratio=5)+ 
  xlim(0,20)+
  theme_bw()+ scale_colour_manual(values=cbbPalette)+scale_fill_manual(values=cbbPalette)+
  geom_segment(x=1, y=0.0, xend=1, yend=1,size=0.05,colour="black",linetype=2)+
  annotate(geom="text", x = 0.5, y = .7, 
           label="1 m", angle=0,
           colour = "black")+
  geom_segment(x=2, y=0., xend=2, yend=1 ,size=0.05,colour="black",linetype=2)+
  annotate(geom="text", x = 2.5, y = .7, 
           label="2 m", angle=0,
           colour = "black")+
geom_segment(x=19.11, y=0., xend=19.11, yend=0.1 ,size=0.05,colour="black",linetype=2)+
  annotate(geom="text", x = 18., y = 0.15, 
           label="Max; iP6 = 19.11 m", angle=0,
           colour = "black")
EWSN_R.d.gg


#Composite Figure
ggarrange(EWSN_F.d.gg,EWSN_T.d.gg,EWSN_R.d.gg,
          nrow=3, heights=c(1.5,1.,1.), labels=c("A","B","C"))
          
#?ggarrange
