#### Accuracy of Smartphone and External Handheld GPS Receivers ####
#### Dec 2023 ####
#### GPS Trials Stats ####
##Grouped RD50s and RD95s
##Boxplot of Grouped stats
############################################
library(Hmisc)
library(ggplot2)
library(ggpubr)
#Load data
setwd("~/Desktop/PC_Folders/LHB/Manuscripts/GPS_Calibration/GPSCalibration_SupplementalData")
list.files(pattern=".csv")

#Load fixed base-station survey data
EWSN_F <-read.csv("Fixed_BaseStation_Survey.csv")
#Load walked transect survey data
EWSN_T <-read.csv("Walked_Transect_Survey.csv")
#Load roaming point survey data
EWSN_R <-read.csv("Roaming_Point_Survey.csv")
####################################################################
####Fixed base-station survey####
##Calculating grouped statistics##
BES_F <-subset(EWSN_F, Receiver=="BES")
BELC_F <-subset(EWSN_F, Receiver=="BELC")
iP12_F <-subset(EWSN_F, Receiver=="iP12")
iP6_F <-subset(EWSN_F, Receiver=="iP6")
#BES
#Select individual Repeat
{BES_F.1 <-subset(BES_F,Repeat==1)
BES_F.2 <-subset(BES_F,Repeat==2)
BES_F.3 <-subset(BES_F,Repeat==3)
BES_F.4 <-subset(BES_F,Repeat==4)
BES_F.5 <-subset(BES_F,Repeat==5)
#Median / RD50
BES_F.1.50 <- quantile(BES_F.1$Dist,.5)
BES_F.2.50 <- quantile(BES_F.2$Dist,.5)
BES_F.3.50 <- quantile(BES_F.3$Dist,.5)
BES_F.4.50 <- quantile(BES_F.4$Dist,.5)
BES_F.5.50 <- quantile(BES_F.5$Dist,.5)
#RD50
BES_F.RD50 <- rbind(BES_F.1.50,
                    BES_F.2.50,
                    BES_F.3.50,
                    BES_F.4.50,
                    BES_F.5.50)
#95th Centile / RD95
BES_F.1.95 <- quantile(BES_F.1$Dist,.95)
BES_F.2.95 <- quantile(BES_F.2$Dist,.95)
BES_F.3.95 <- quantile(BES_F.3$Dist,.95)
BES_F.4.95 <- quantile(BES_F.4$Dist,.95)
BES_F.5.95 <- quantile(BES_F.5$Dist,.95)
#RD95
BES_F.RD95 <- rbind(BES_F.1.95,
                    BES_F.2.95,
                    BES_F.3.95,
                    BES_F.4.95,
                    BES_F.5.95)
#Number of measurements
BES_F.1.n <- nrow(BES_F.1)
BES_F.2.n <- nrow(BES_F.2)
BES_F.3.n <- nrow(BES_F.3)
BES_F.4.n <- nrow(BES_F.4)
BES_F.5.n <- nrow(BES_F.5)

#numbers=n
BES_F.n    <- rbind(BES_F.1.n,
                    BES_F.2.n,
                    BES_F.3.n,
                    BES_F.4.n,
                    BES_F.5.n)
#df of group statistics
BES_F.gr <-data.frame(seq(1,5,1),
                      "BES",
                      BES_F.RD50,
                      BES_F.RD95,
                      BES_F.n)
rownames(BES_F.gr) <- NULL
colnames(BES_F.gr) <-c("Repeat","Receiver","RD50","RD95","n") 
}
BES_F.gr

library(Hmisc)
#?wtd.mean
#?wtd.var
wtd.mean(BES_F.gr$RD50,BES_F.gr$n)
sqrt(wtd.var(BES_F.gr$RD50,BES_F.gr$n))
wtd.mean(BES_F.gr$RD95,BES_F.gr$n)
sqrt(wtd.var(BES_F.gr$RD95,BES_F.gr$n))
BES_F[which.max(BES_F$Dist),]
mean(BES_F.gr$n)
boxplot(BES_F.gr$RD50,BES_F.gr$RD95)
#?wtd.mean
#BELC
#Select individual Repeat
BELC_F.1 <-subset(BELC_F,Repeat==1)
BELC_F.2 <-subset(BELC_F,Repeat==2)
BELC_F.3 <-subset(BELC_F,Repeat==3)
BELC_F.4 <-subset(BELC_F,Repeat==4)
BELC_F.5 <-subset(BELC_F,Repeat==5)
#Median / RD50
{BELC_F.1.50 <- quantile(BELC_F.1$Dist,.5)
BELC_F.2.50 <- quantile(BELC_F.2$Dist,.5)
BELC_F.3.50 <- quantile(BELC_F.3$Dist,.5)
BELC_F.4.50 <- quantile(BELC_F.4$Dist,.5)
BELC_F.5.50 <- quantile(BELC_F.5$Dist,.5)
#RD50
BELC_F.RD50 <- rbind(BELC_F.1.50,
                     BELC_F.2.50,
                     BELC_F.3.50,
                     BELC_F.4.50,
                     BELC_F.5.50)
#95th Centile / RD95
BELC_F.1.95 <- quantile(BELC_F.1$Dist,.95)
BELC_F.2.95 <- quantile(BELC_F.2$Dist,.95)
BELC_F.3.95 <- quantile(BELC_F.3$Dist,.95)
BELC_F.4.95 <- quantile(BELC_F.4$Dist,.95)
BELC_F.5.95 <- quantile(BELC_F.5$Dist,.95)
#RD95
BELC_F.RD95 <- rbind(BELC_F.1.95,
                     BELC_F.2.95,
                     BELC_F.3.95,
                     BELC_F.4.95,
                     BELC_F.5.95)
#Number of measurements
BELC_F.1.n <- nrow(BELC_F.1)
BELC_F.2.n <- nrow(BELC_F.2)
BELC_F.3.n <- nrow(BELC_F.3)
BELC_F.4.n <- nrow(BELC_F.4)
BELC_F.5.n <- nrow(BELC_F.5)

#numbers=n
BELC_F.n    <- rbind(BELC_F.1.n,
                     BELC_F.2.n,
                     BELC_F.3.n,
                     BELC_F.4.n,
                     BELC_F.5.n)
#df

BELC_F.gr <-data.frame(seq(1,5,1),
                        "BELC",
                        BELC_F.RD50,
                        BELC_F.RD95,
                        BELC_F.n)
rownames(BELC_F.gr) <- NULL
colnames(BELC_F.gr) <-c("Repeat","Receiver","RD50","RD95","n") 
}
BELC_F.gr

wtd.mean(BELC_F.gr$RD50,BELC_F.gr$n)
sqrt(wtd.var(BELC_F.gr$RD50,BELC_F.gr$n))
wtd.mean(BELC_F.gr$RD95,BELC_F.gr$n)
sqrt(wtd.var(BELC_F.gr$RD95,BELC_F.gr$n))
BELC_F[which.max(BELC_F$Dist),]
mean(BELC_F.gr$n)
boxplot(BELC_F.gr$RD50,BELC_F.gr$RD95)

#iP6
#Select individual Repeat
iP6_F.1 <-subset(iP6_F,Repeat==1)
iP6_F.2 <-subset(iP6_F,Repeat==2)
iP6_F.3 <-subset(iP6_F,Repeat==3)
iP6_F.4 <-subset(iP6_F,Repeat==4)
iP6_F.5 <-subset(iP6_F,Repeat==5)
#Median / RD50
{iP6_F.1.50 <- quantile(iP6_F.1$Dist,.5)
iP6_F.2.50 <- quantile(iP6_F.2$Dist,.5)
iP6_F.3.50 <- quantile(iP6_F.3$Dist,.5)
iP6_F.4.50 <- quantile(iP6_F.4$Dist,.5)
iP6_F.5.50 <- quantile(iP6_F.5$Dist,.5)
#RD50
iP6_F.RD50 <- rbind(iP6_F.1.50,
                    iP6_F.2.50,
                    iP6_F.3.50,
                    iP6_F.4.50,
                    iP6_F.5.50)
#95th Centile / RD95
iP6_F.1.95 <- quantile(iP6_F.1$Dist,.95)
iP6_F.2.95 <- quantile(iP6_F.2$Dist,.95)
iP6_F.3.95 <- quantile(iP6_F.3$Dist,.95)
iP6_F.4.95 <- quantile(iP6_F.4$Dist,.95)
iP6_F.5.95 <- quantile(iP6_F.5$Dist,.95)
#RD95
iP6_F.RD95 <- rbind(iP6_F.1.95,
                    iP6_F.2.95,
                    iP6_F.3.95,
                    iP6_F.4.95,
                    iP6_F.5.95)
#Number of measurements
iP6_F.1.n <- nrow(iP6_F.1)
iP6_F.2.n <- nrow(iP6_F.2)
iP6_F.3.n <- nrow(iP6_F.3)
iP6_F.4.n <- nrow(iP6_F.4)
iP6_F.5.n <- nrow(iP6_F.5)

#numbers=n
iP6_F.n    <- rbind(iP6_F.1.n,
                    iP6_F.2.n,
                    iP6_F.3.n,
                    iP6_F.4.n,
                    iP6_F.5.n)
#df

iP6_F.gr <-data.frame( seq(1,5,1),
                       "iP6",
                       iP6_F.RD50,
                       iP6_F.RD95,
                       iP6_F.n)
rownames(iP6_F.gr) <- NULL
colnames(iP6_F.gr) <-c("Repeat","Receiver","RD50","RD95","n") 
}
iP6_F.gr
#weighted means and weighted sd
wtd.mean(iP6_F.gr$RD50,iP6_F.gr$n)
sqrt(wtd.var(iP6_F.gr$RD50,iP6_F.gr$n))
wtd.mean(iP6_F.gr$RD95,iP6_F.gr$n)
sqrt(wtd.var(iP6_F.gr$RD95,iP6_F.gr$n))
iP6_F[which.max(iP6_F$Dist),]
mean(iP6_F.gr$n)
boxplot(iP6_F.gr$RD50,iP6_F.gr$RD95)

#iP12
#Select individual Repeat
iP12_F.1 <-subset(iP12_F,Repeat==1)
iP12_F.2 <-subset(iP12_F,Repeat==2)
iP12_F.3 <-subset(iP12_F,Repeat==3)
iP12_F.4 <-subset(iP12_F,Repeat==4)
iP12_F.5 <-subset(iP12_F,Repeat==5)
#Median / 50th Percentile / RD50
{iP12_F.1.50 <- quantile(iP12_F.1$Dist,.5)
iP12_F.2.50 <- quantile(iP12_F.2$Dist,.5)
iP12_F.3.50 <- quantile(iP12_F.3$Dist,.5)
iP12_F.4.50 <- quantile(iP12_F.4$Dist,.5)
iP12_F.5.50 <- quantile(iP12_F.5$Dist,.5)
#RD50
iP12_F.RD50 <- rbind(iP12_F.1.50,
                     iP12_F.2.50,
                     iP12_F.3.50,
                     iP12_F.4.50,
                     iP12_F.5.50)
#95th Centile / RD95
iP12_F.1.95 <- quantile(iP12_F.1$Dist,.95)
iP12_F.2.95 <- quantile(iP12_F.2$Dist,.95)
iP12_F.3.95 <- quantile(iP12_F.3$Dist,.95)
iP12_F.4.95 <- quantile(iP12_F.4$Dist,.95)
iP12_F.5.95 <- quantile(iP12_F.5$Dist,.95)
#RD95
iP12_F.RD95 <- rbind(iP12_F.1.95,
                     iP12_F.2.95,
                     iP12_F.3.95,
                     iP12_F.4.95,
                     iP12_F.5.95)
#Number of measurements
iP12_F.1.n <- nrow(iP12_F.1)
iP12_F.2.n <- nrow(iP12_F.2)
iP12_F.3.n <- nrow(iP12_F.3)
iP12_F.4.n <- nrow(iP12_F.4)
iP12_F.5.n <- nrow(iP12_F.5)

#numbers=n
iP12_F.n    <- rbind(iP12_F.1.n,
                     iP12_F.2.n,
                     iP12_F.3.n,
                     iP12_F.4.n,
                     iP12_F.5.n)
#df
iP12_F.gr <-data.frame(seq(1,5,1),
                       "iP12",
                       iP12_F.RD50,
                       iP12_F.RD95,
                       iP12_F.n)
rownames(iP12_F.gr) <- NULL
colnames(iP12_F.gr) <-c("Repeat","Receiver","RD50","RD95","n") 
}
iP12_F.gr
wtd.mean(iP12_F.gr$RD50,iP12_F.gr$n)
sqrt(wtd.var(iP12_F.gr$RD50,iP12_F.gr$n))
wtd.mean(iP12_F.gr$RD95,iP12_F.gr$n)
sqrt(wtd.var(iP12_F.gr$RD95,iP12_F.gr$n))
iP12_F[which.max(iP12_F$Dist),]
mean(iP12_F.gr$n)
boxplot(iP12_F.gr$RD50,iP12_F.gr$RD95)


###################################################################

####Walked transect survey#### 
##Calculating grouped statistics##
BES_T <-subset(EWSN_T, Receiver=="BES")
BELC_T <-subset(EWSN_T, Receiver=="BELC")
iP12_T <-subset(EWSN_T, Receiver=="iP12")
iP6_T <-subset(EWSN_T, Receiver=="iP6")
#BES
#Select individual Repeat
  {BES_T.1 <-subset(BES_T,Repeat==1)
  BES_T.2 <-subset(BES_T,Repeat==2)
  BES_T.3 <-subset(BES_T,Repeat==3)
  BES_T.4 <-subset(BES_T,Repeat==4)
  BES_T.5 <-subset(BES_T,Repeat==5)
  #Median / RD50
  BES_T.1.50 <- quantile(BES_T.1$d,.5)
  BES_T.2.50 <- quantile(BES_T.2$d,.5)
  BES_T.3.50 <- quantile(BES_T.3$d,.5)
  BES_T.4.50 <- quantile(BES_T.4$d,.5)
  BES_T.5.50 <- quantile(BES_T.5$d,.5)
  #RD50
  BES_T.RD50 <- rbind(BES_T.1.50,
                      BES_T.2.50,
                      BES_T.3.50,
                      BES_T.4.50,
                      BES_T.5.50)
  #95th Centile / RD95
  BES_T.1.95 <- quantile(BES_T.1$d,.95)
  BES_T.2.95 <- quantile(BES_T.2$d,.95)
  BES_T.3.95 <- quantile(BES_T.3$d,.95)
  BES_T.4.95 <- quantile(BES_T.4$d,.95)
  BES_T.5.95 <- quantile(BES_T.5$d,.95)
  #RD95
  BES_T.RD95 <- rbind(BES_T.1.95,
                      BES_T.2.95,
                      BES_T.3.95,
                      BES_T.4.95,
                      BES_T.5.95)
  #Number of measurements
  BES_T.1.n <- nrow(BES_T.1)
  BES_T.2.n <- nrow(BES_T.2)
  BES_T.3.n <- nrow(BES_T.3)
  BES_T.4.n <- nrow(BES_T.4)
  BES_T.5.n <- nrow(BES_T.5)
  
  #numbers=n
  BES_T.n    <- rbind(BES_T.1.n,
                      BES_T.2.n,
                      BES_T.3.n,
                      BES_T.4.n,
                      BES_T.5.n)
  #df of group statistics
  BES_T.gr <-data.frame(seq(1,5,1),
                        "BES",
                        BES_T.RD50,
                        BES_T.RD95,
                        BES_T.n)
  rownames(BES_T.gr) <- NULL
  colnames(BES_T.gr) <-c("Repeat","Receiver","RD50","RD95","n") 
}
BES_T.gr

#library(Hmisc)
wtd.mean(BES_T.gr$RD50,BES_T.gr$n)
sqrt(wtd.var(BES_T.gr$RD50,BES_T.gr$n))
wtd.mean(BES_T.gr$RD95,BES_T.gr$n)
sqrt(wtd.var(BES_T.gr$RD95,BES_T.gr$n))
BES_T[which.max(BES_T$d),]
mean(BES_T.gr$n)
boxplot(BES_T.gr$RD50,BES_T.gr$RD95)

#BELC
#Select individual Repeat
BELC_T.1 <-subset(BELC_T,Repeat==1)
BELC_T.2 <-subset(BELC_T,Repeat==2)
BELC_T.3 <-subset(BELC_T,Repeat==3)
BELC_T.4 <-subset(BELC_T,Repeat==4)
BELC_T.5 <-subset(BELC_T,Repeat==5)
#Median / RD50
 {BELC_T.1.50 <- quantile(BELC_T.1$d,.5)
  BELC_T.2.50 <- quantile(BELC_T.2$d,.5)
  BELC_T.3.50 <- quantile(BELC_T.3$d,.5)
  BELC_T.4.50 <- quantile(BELC_T.4$d,.5)
  BELC_T.5.50 <- quantile(BELC_T.5$d,.5)
  #RD50
  BELC_T.RD50 <- rbind(BELC_T.1.50,
                       BELC_T.2.50,
                       BELC_T.3.50,
                       BELC_T.4.50,
                       BELC_T.5.50)
  #95th Centile / RD95
  BELC_T.1.95 <- quantile(BELC_T.1$d,.95)
  BELC_T.2.95 <- quantile(BELC_T.2$d,.95)
  BELC_T.3.95 <- quantile(BELC_T.3$d,.95)
  BELC_T.4.95 <- quantile(BELC_T.4$d,.95)
  BELC_T.5.95 <- quantile(BELC_T.5$d,.95)
  #RD95
  BELC_T.RD95 <- rbind(BELC_T.1.95,
                       BELC_T.2.95,
                       BELC_T.3.95,
                       BELC_T.4.95,
                       BELC_T.5.95)
  #Number of measurements
  BELC_T.1.n <- nrow(BELC_T.1)
  BELC_T.2.n <- nrow(BELC_T.2)
  BELC_T.3.n <- nrow(BELC_T.3)
  BELC_T.4.n <- nrow(BELC_T.4)
  BELC_T.5.n <- nrow(BELC_T.5)
  #numbers=n
  BELC_T.n    <- rbind(BELC_T.1.n,
                       BELC_T.2.n,
                       BELC_T.3.n,
                       BELC_T.4.n,
                       BELC_T.5.n)
  #df
  BELC_T.gr <-data.frame(seq(1,5,1),
                         "BELC",
                         BELC_T.RD50,
                         BELC_T.RD95,
                         BELC_T.n)
  rownames(BELC_T.gr) <- NULL
  colnames(BELC_T.gr) <-c("Repeat","Receiver","RD50","RD95","n") 
}
BELC_T.gr

wtd.mean(BELC_T.gr$RD50,BELC_T.gr$n)
sqrt(wtd.var(BELC_T.gr$RD50,BELC_T.gr$n))
wtd.mean(BELC_T.gr$RD95,BELC_T.gr$n)
sqrt(wtd.var(BELC_T.gr$RD95,BELC_T.gr$n))
BELC_T[which.max(BELC_T$d),]
mean(BELC_T.gr$n)
boxplot(BELC_T.gr$RD50,BELC_T.gr$RD95)

#iP6
#Select individual Repeat
iP6_T.1 <-subset(iP6_T,Repeat==1)
iP6_T.2 <-subset(iP6_T,Repeat==2)
iP6_T.3 <-subset(iP6_T,Repeat==3)
iP6_T.4 <-subset(iP6_T,Repeat==4)
iP6_T.5 <-subset(iP6_T,Repeat==5)
#Median / RD50
{iP6_T.1.50 <- quantile(iP6_T.1$d,.5)
  iP6_T.2.50 <- quantile(iP6_T.2$d,.5)
  iP6_T.3.50 <- quantile(iP6_T.3$d,.5)
  iP6_T.4.50 <- quantile(iP6_T.4$d,.5)
  iP6_T.5.50 <- quantile(iP6_T.5$d,.5)
  #RD50
  iP6_T.RD50 <- rbind(iP6_T.1.50,
                      iP6_T.2.50,
                      iP6_T.3.50,
                      iP6_T.4.50,
                      iP6_T.5.50)
  #95th Centile / RD95
  iP6_T.1.95 <- quantile(iP6_T.1$d,.95)
  iP6_T.2.95 <- quantile(iP6_T.2$d,.95)
  iP6_T.3.95 <- quantile(iP6_T.3$d,.95)
  iP6_T.4.95 <- quantile(iP6_T.4$d,.95)
  iP6_T.5.95 <- quantile(iP6_T.5$d,.95)
  #RD95
  iP6_T.RD95 <- rbind(iP6_T.1.95,
                      iP6_T.2.95,
                      iP6_T.3.95,
                      iP6_T.4.95,
                      iP6_T.5.95)
  #Number of measurements
  iP6_T.1.n <- nrow(iP6_T.1)
  iP6_T.2.n <- nrow(iP6_T.2)
  iP6_T.3.n <- nrow(iP6_T.3)
  iP6_T.4.n <- nrow(iP6_T.4)
  iP6_T.5.n <- nrow(iP6_T.5)
  
  #numbers=n
  iP6_T.n    <- rbind(iP6_T.1.n,
                      iP6_T.2.n,
                      iP6_T.3.n,
                      iP6_T.4.n,
                      iP6_T.5.n)
  #df
  
  iP6_T.gr <-data.frame( seq(1,5,1),
                         "iP6",
                         iP6_T.RD50,
                         iP6_T.RD95,
                         iP6_T.n)
  rownames(iP6_T.gr) <- NULL
  colnames(iP6_T.gr) <-c("Repeat","Receiver","RD50","RD95","n") 
}
iP6_T.gr
#weighted means and weighted sd
wtd.mean(iP6_T.gr$RD50,iP6_T.gr$n)
sqrt(wtd.var(iP6_T.gr$RD50,iP6_T.gr$n))
wtd.mean(iP6_T.gr$RD95,iP6_T.gr$n)
sqrt(wtd.var(iP6_T.gr$RD95,iP6_T.gr$n))
iP6_T[which.max(iP6_T$d),]
mean(iP6_T.gr$n)
boxplot(iP6_T.gr$RD50,iP6_T.gr$RD95)

#iP12
#Select individual Repeat
iP12_T.1 <-subset(iP12_T,Repeat==1)
iP12_T.2 <-subset(iP12_T,Repeat==2)
iP12_T.3 <-subset(iP12_T,Repeat==3)
iP12_T.4 <-subset(iP12_T,Repeat==4)
iP12_T.5 <-subset(iP12_T,Repeat==5)
#Median / 50th Percentile / RD50
{iP12_T.1.50 <- quantile(iP12_T.1$d,.5)
  iP12_T.2.50 <- quantile(iP12_T.2$d,.5)
  iP12_T.3.50 <- quantile(iP12_T.3$d,.5)
  iP12_T.4.50 <- quantile(iP12_T.4$d,.5)
  iP12_T.5.50 <- quantile(iP12_T.5$d,.5)
  #RD50
  iP12_T.RD50 <- rbind(iP12_T.1.50,
                       iP12_T.2.50,
                       iP12_T.3.50,
                       iP12_T.4.50,
                       iP12_T.5.50)
  #95th Centile / RD95
  iP12_T.1.95 <- quantile(iP12_T.1$d,.95)
  iP12_T.2.95 <- quantile(iP12_T.2$d,.95)
  iP12_T.3.95 <- quantile(iP12_T.3$d,.95)
  iP12_T.4.95 <- quantile(iP12_T.4$d,.95)
  iP12_T.5.95 <- quantile(iP12_T.5$d,.95)
  #RD95
  iP12_T.RD95 <- rbind(iP12_T.1.95,
                       iP12_T.2.95,
                       iP12_T.3.95,
                       iP12_T.4.95,
                       iP12_T.5.95)
  #Number of measurements
  iP12_T.1.n <- nrow(iP12_T.1)
  iP12_T.2.n <- nrow(iP12_T.2)
  iP12_T.3.n <- nrow(iP12_T.3)
  iP12_T.4.n <- nrow(iP12_T.4)
  iP12_T.5.n <- nrow(iP12_T.5)
  
  #numbers=n
  iP12_T.n    <- rbind(iP12_T.1.n,
                       iP12_T.2.n,
                       iP12_T.3.n,
                       iP12_T.4.n,
                       iP12_T.5.n)
  #df
  iP12_T.gr <-data.frame(seq(1,5,1),
                         "iP12",
                         iP12_T.RD50,
                         iP12_T.RD95,
                         iP12_T.n)
  rownames(iP12_T.gr) <- NULL
  colnames(iP12_T.gr) <-c("Repeat","Receiver","RD50","RD95","n") 
}
iP12_T.gr
wtd.mean(iP12_T.gr$RD50,iP12_T.gr$n)
sqrt(wtd.var(iP12_T.gr$RD50,iP12_T.gr$n))
wtd.mean(iP12_T.gr$RD95,iP12_T.gr$n)
sqrt(wtd.var(iP12_T.gr$RD95,iP12_T.gr$n))
iP12_T[which.max(iP12_T$d),]
mean(iP12_T.gr$n)
boxplot(iP12_T.gr$RD50,iP12_T.gr$RD95)

############################################################

####Roaming point survey####
##Calculating grouped statistics##
BES_R <-subset(EWSN_R, Receiver=="BES")
BELC_R <-subset(EWSN_R, Receiver=="BELC")
iP12_R <-subset(EWSN_R, Receiver=="iP12")
iP6_R <-subset(EWSN_R, Receiver=="iP6")
#BES
#Select individual Repeat
{BES_R.1 <-subset(BES_R,Repeat==1)
  BES_R.2 <-subset(BES_R,Repeat==2)
  BES_R.3 <-subset(BES_R,Repeat==3)
  BES_R.4 <-subset(BES_R,Repeat==4)
  BES_R.5 <-subset(BES_R,Repeat==5)
  #Median / RD50
  BES_R.1.50 <- quantile(BES_R.1$Dist,.5)
  BES_R.2.50 <- quantile(BES_R.2$Dist,.5)
  BES_R.3.50 <- quantile(BES_R.3$Dist,.5)
  BES_R.4.50 <- quantile(BES_R.4$Dist,.5)
  BES_R.5.50 <- quantile(BES_R.5$Dist,.5)
  #RD50
  BES_R.RD50 <- rbind(BES_R.1.50,
                      BES_R.2.50,
                      BES_R.3.50,
                      BES_R.4.50,
                      BES_R.5.50)
  #95th Centile / RD95
  BES_R.1.95 <- quantile(BES_R.1$Dist,.95)
  BES_R.2.95 <- quantile(BES_R.2$Dist,.95)
  BES_R.3.95 <- quantile(BES_R.3$Dist,.95)
  BES_R.4.95 <- quantile(BES_R.4$Dist,.95)
  BES_R.5.95 <- quantile(BES_R.5$Dist,.95)
  #RD95
  BES_R.RD95 <- rbind(BES_R.1.95,
                      BES_R.2.95,
                      BES_R.3.95,
                      BES_R.4.95,
                      BES_R.5.95)
  #Number of measurements
  BES_R.1.n <- nrow(BES_R.1)
  BES_R.2.n <- nrow(BES_R.2)
  BES_R.3.n <- nrow(BES_R.3)
  BES_R.4.n <- nrow(BES_R.4)
  BES_R.5.n <- nrow(BES_R.5)
  #numbers=n
  BES_R.n    <- rbind(BES_R.1.n,
                      BES_R.2.n,
                      BES_R.3.n,
                      BES_R.4.n,
                      BES_R.5.n)
  #df of group statistics
  BES_R.gr <-data.frame(seq(1,5,1),
                        "BES",
                        BES_R.RD50,
                        BES_R.RD95,
                        BES_R.n)
  rownames(BES_R.gr) <- NULL
  colnames(BES_R.gr) <-c("Repeat","Receiver","RD50","RD95","n") 
}
BES_R.gr

#library(Hmisc)
wtd.mean(BES_R.gr$RD50,BES_R.gr$n)
sqrt(wtd.var(BES_R.gr$RD50,BES_R.gr$n))
wtd.mean(BES_R.gr$RD95,BES_R.gr$n)
sqrt(wtd.var(BES_R.gr$RD95,BES_R.gr$n))
BES_R[which.max(BES_R$Dist),]
mean(BES_R.gr$n)
boxplot(BES_R.gr$RD50,BES_R.gr$RD95)
#?wtd.mean
#BELC
#Select individual Repeat
BELC_R.1 <-subset(BELC_R,Repeat==1)
BELC_R.2 <-subset(BELC_R,Repeat==2)
BELC_R.3 <-subset(BELC_R,Repeat==3)
BELC_R.4 <-subset(BELC_R,Repeat==4)
BELC_R.5 <-subset(BELC_R,Repeat==5)
#Median / RD50
{BELC_R.1.50 <- quantile(BELC_R.1$Dist,.5)
  BELC_R.2.50 <- quantile(BELC_R.2$Dist,.5)
  BELC_R.3.50 <- quantile(BELC_R.3$Dist,.5)
  BELC_R.4.50 <- quantile(BELC_R.4$Dist,.5)
  BELC_R.5.50 <- quantile(BELC_R.5$Dist,.5)
  #RD50
  BELC_R.RD50 <- rbind(BELC_R.1.50,
                       BELC_R.2.50,
                       BELC_R.3.50,
                       BELC_R.4.50,
                       BELC_R.5.50)
  #95th Centile / RD95
  BELC_R.1.95 <- quantile(BELC_R.1$Dist,.95)
  BELC_R.2.95 <- quantile(BELC_R.2$Dist,.95)
  BELC_R.3.95 <- quantile(BELC_R.3$Dist,.95)
  BELC_R.4.95 <- quantile(BELC_R.4$Dist,.95)
  BELC_R.5.95 <- quantile(BELC_R.5$Dist,.95)
  #RD95
  BELC_R.RD95 <- rbind(BELC_R.1.95,
                       BELC_R.2.95,
                       BELC_R.3.95,
                       BELC_R.4.95,
                       BELC_R.5.95)
  #Number of measurements
  BELC_R.1.n <- nrow(BELC_R.1)
  BELC_R.2.n <- nrow(BELC_R.2)
  BELC_R.3.n <- nrow(BELC_R.3)
  BELC_R.4.n <- nrow(BELC_R.4)
  BELC_R.5.n <- nrow(BELC_R.5)
  #numbers=n
  BELC_R.n    <- rbind(BELC_R.1.n,
                       BELC_R.2.n,
                       BELC_R.3.n,
                       BELC_R.4.n,
                       BELC_R.5.n)
  #df
  BELC_R.gr <-data.frame(seq(1,5,1),
                         "BELC",
                         BELC_R.RD50,
                         BELC_R.RD95,
                         BELC_R.n)
  rownames(BELC_R.gr) <- NULL
  colnames(BELC_R.gr) <-c("Repeat","Receiver","RD50","RD95","n") 
}
BELC_R.gr

wtd.mean(BELC_R.gr$RD50,BELC_R.gr$n)
sqrt(wtd.var(BELC_R.gr$RD50,BELC_R.gr$n))
wtd.mean(BELC_R.gr$RD95,BELC_R.gr$n)
sqrt(wtd.var(BELC_R.gr$RD95,BELC_R.gr$n))
BELC_R[which.max(BELC_R$Dist),]
mean(BELC_R.gr$n)
boxplot(BELC_R.gr$RD50,BELC_R.gr$RD95)

#iP6
#Select individual Repeat
iP6_R.1 <-subset(iP6_R,Repeat==1)
iP6_R.2 <-subset(iP6_R,Repeat==2)
iP6_R.3 <-subset(iP6_R,Repeat==3)
iP6_R.4 <-subset(iP6_R,Repeat==4)
iP6_R.5 <-subset(iP6_R,Repeat==5)
#Median / RD50
{iP6_R.1.50 <- quantile(iP6_R.1$Dist,.5)
  iP6_R.2.50 <- quantile(iP6_R.2$Dist,.5)
  iP6_R.3.50 <- quantile(iP6_R.3$Dist,.5)
  iP6_R.4.50 <- quantile(iP6_R.4$Dist,.5)
  iP6_R.5.50 <- quantile(iP6_R.5$Dist,.5)
  #RD50
  iP6_R.RD50 <- rbind(iP6_R.1.50,
                      iP6_R.2.50,
                      iP6_R.3.50,
                      iP6_R.4.50,
                      iP6_R.5.50)
  #95th Centile / RD95
  iP6_R.1.95 <- quantile(iP6_R.1$Dist,.95)
  iP6_R.2.95 <- quantile(iP6_R.2$Dist,.95)
  iP6_R.3.95 <- quantile(iP6_R.3$Dist,.95)
  iP6_R.4.95 <- quantile(iP6_R.4$Dist,.95)
  iP6_R.5.95 <- quantile(iP6_R.5$Dist,.95)
  #RD95
  iP6_R.RD95 <- rbind(iP6_R.1.95,
                      iP6_R.2.95,
                      iP6_R.3.95,
                      iP6_R.4.95,
                      iP6_R.5.95)
  #Number of measurements
  iP6_R.1.n <- nrow(iP6_R.1)
  iP6_R.2.n <- nrow(iP6_R.2)
  iP6_R.3.n <- nrow(iP6_R.3)
  iP6_R.4.n <- nrow(iP6_R.4)
  iP6_R.5.n <- nrow(iP6_R.5)
  #numbers=n
  iP6_R.n    <- rbind(iP6_R.1.n,
                      iP6_R.2.n,
                      iP6_R.3.n,
                      iP6_R.4.n,
                      iP6_R.5.n)
  #df
  iP6_R.gr <-data.frame( seq(1,5,1),
                         "iP6",
                         iP6_R.RD50,
                         iP6_R.RD95,
                         iP6_R.n)
  rownames(iP6_R.gr) <- NULL
  colnames(iP6_R.gr) <-c("Repeat","Receiver","RD50","RD95","n") 
}
iP6_R.gr
#weighted means and weighted sd
wtd.mean(iP6_R.gr$RD50,iP6_R.gr$n)
sqrt(wtd.var(iP6_R.gr$RD50,iP6_R.gr$n))
wtd.mean(iP6_R.gr$RD95,iP6_R.gr$n)
sqrt(wtd.var(iP6_R.gr$RD95,iP6_R.gr$n))
iP6_R[which.max(iP6_R$Dist),]
mean(iP6_R.gr$n)
boxplot(iP6_R.gr$RD50,iP6_R.gr$RD95)

#iP12
#Select individual Repeat
iP12_R.1 <-subset(iP12_R,Repeat==1)
iP12_R.2 <-subset(iP12_R,Repeat==2)
iP12_R.3 <-subset(iP12_R,Repeat==3)
iP12_R.4 <-subset(iP12_R,Repeat==4)
iP12_R.5 <-subset(iP12_R,Repeat==5)
#Median / 50th Percentile / RD50
{iP12_R.1.50 <- quantile(iP12_R.1$Dist,.5)
  iP12_R.2.50 <- quantile(iP12_R.2$Dist,.5)
  iP12_R.3.50 <- quantile(iP12_R.3$Dist,.5)
  iP12_R.4.50 <- quantile(iP12_R.4$Dist,.5)
  iP12_R.5.50 <- quantile(iP12_R.5$Dist,.5)
  #RD50
  iP12_R.RD50 <- rbind(iP12_R.1.50,
                       iP12_R.2.50,
                       iP12_R.3.50,
                       iP12_R.4.50,
                       iP12_R.5.50)
  #95th Centile / RD95
  iP12_R.1.95 <- quantile(iP12_R.1$Dist,.95)
  iP12_R.2.95 <- quantile(iP12_R.2$Dist,.95)
  iP12_R.3.95 <- quantile(iP12_R.3$Dist,.95)
  iP12_R.4.95 <- quantile(iP12_R.4$Dist,.95)
  iP12_R.5.95 <- quantile(iP12_R.5$Dist,.95)
  #RD95
  iP12_R.RD95 <- rbind(iP12_R.1.95,
                       iP12_R.2.95,
                       iP12_R.3.95,
                       iP12_R.4.95,
                       iP12_R.5.95)
  #Number of measurements
  iP12_R.1.n <- nrow(iP12_R.1)
  iP12_R.2.n <- nrow(iP12_R.2)
  iP12_R.3.n <- nrow(iP12_R.3)
  iP12_R.4.n <- nrow(iP12_R.4)
  iP12_R.5.n <- nrow(iP12_R.5)
  #numbers=n
  iP12_R.n    <- rbind(iP12_R.1.n,
                       iP12_R.2.n,
                       iP12_R.3.n,
                       iP12_R.4.n,
                       iP12_R.5.n)
  #df
  iP12_R.gr <-data.frame(seq(1,5,1),
                         "iP12",
                         iP12_R.RD50,
                         iP12_R.RD95,
                         iP12_R.n)
  rownames(iP12_R.gr) <- NULL
  colnames(iP12_R.gr) <-c("Repeat","Receiver","RD50","RD95","n") 
}
iP12_R.gr
wtd.mean(iP12_R.gr$RD50,iP12_R.gr$n)
sqrt(wtd.var(iP12_R.gr$RD50,iP12_R.gr$n))
wtd.mean(iP12_R.gr$RD95,iP12_R.gr$n)
sqrt(wtd.var(iP12_R.gr$RD95,iP12_R.gr$n))
iP12_R[which.max(iP12_R$Dist),]
mean(iP12_R.gr$n)
boxplot(iP12_R.gr$RD50,iP12_R.gr$RD95)


boxplot(ylim=c(0,16),BES_R.gr$RD50,BES_R.gr$RD95,BELC_R.gr$RD50, BELC_R.gr$RD95,iP6_R.gr$RD50,iP6_R.gr$RD95,iP12_R.gr$RD50,iP12_R.gr$RD95)

###############################################################
####gg Boxplots####

# Colour blind palette with black:
cbbPalette <- c("#0072B2","#000000", "#E69F00","#009E73")

F.gr <-rbind(BES_F.gr,BELC_F.gr,iP6_F.gr,iP12_F.gr)
names(F.gr)

#boxplot RD50
F.gg.50 <-ggplot(data=F.gr, 
                 aes(y=factor(Receiver,levels=c("iP6","iP12","BES","BELC")),x=RD50, fill=Receiver,color=Receiver))+
  #xlim(0,15)+ 
  xlab("Fixed Base Station Survey: Distribution of Grouped RD50s (m)")+ylab("Receiver")+
  geom_boxplot(alpha=.4)+theme_bw()+
  scale_colour_manual(values=cbbPalette)+scale_fill_manual(values=cbbPalette)+
  geom_vline(xintercept = c(1,2), linetype=3, color="black")+
  annotate(geom="text", x = 0.25, y = 4.5, 
           label="1 m", angle=0,
           colour = "black")+
  annotate(geom="text", x = 2.75, y = 4.5, 
           label="2 m", angle=0,
           colour = "black")
F.gg.50
#Boxplot RD95
F.gg.95 <-ggplot(data=F.gr, 
                 aes(y=factor(Receiver,levels=c("iP6","iP12","BES","BELC")),x=RD95, fill=Receiver,color=Receiver))+
  xlim(0,20)+ 
  xlab("Fixed Base Station Survey: Distribution of Grouped RD95s (m)")+ylab("Receiver")+
  geom_boxplot(alpha=.4)+theme_bw()+
  scale_colour_manual(values=cbbPalette)+scale_fill_manual(values=cbbPalette)+
  geom_vline(xintercept = c(1,2), linetype=3, color="black")+
  annotate(geom="text", x = 0.25, y = 4.5, 
           label="1 m", angle=0,
           colour = "black")+
  annotate(geom="text", x = 2.75, y = 4.5, 
           label="2 m", angle=0,
           colour = "black")+
  annotate(geom="Point", x = 5.39, y = 4.2, pch=18,cex=4,#BELC
           colour = "#0072B2")+
  annotate(geom="Point", x = 3.85, y = 3, pch=18,cex=4,#BES
           colour = "#000000")+
  annotate(geom="Point", x = 14.44, y = 2, pch=18,cex=4,#iP12
           colour = "#E69F00")+
  annotate(geom="Point", x = 11.64, y = 1, pch=18,cex=4,#iP6
           colour = "#009E73")
F.gg.95
?pch
####
T.gr <-rbind(BES_T.gr,BELC_T.gr,iP6_T.gr,iP12_T.gr)
names(T.gr)
#boxplot RD50
T.gg.50 <-ggplot(data=T.gr, 
                 aes(y=factor(Receiver,levels=c("iP6","iP12","BES","BELC")),x=RD50, fill=Receiver,color=Receiver))+
  xlim(0,15)+ 
  xlab("Walked Transect Survey: Distribution of Grouped 50th Centiles (m)")+ylab("Receiver")+
  geom_boxplot(alpha=.4)+theme_bw()+
  scale_colour_manual(values=cbbPalette)+scale_fill_manual(values=cbbPalette)+
  geom_vline(xintercept = c(1,2), linetype=3, color="black")+
  annotate(geom="text", x = 0.25, y = 4.5, 
           label="1 m", angle=0,
           colour = "black")+
  annotate(geom="text", x = 2.75, y = 4.5, 
           label="2 m", angle=0,
           colour = "black")+
  annotate(geom="text", x = 2.75, y = 4.5, 
           label="2 m", angle=0,
           colour = "black")
T.gg.50
#Boxplot RD95
T.gg.95 <-ggplot(data=T.gr, 
                 aes(y=factor(Receiver,levels=c("iP6","iP12","BES","BELC")),x=RD95, fill=Receiver,color=Receiver))+
  xlim(0,20)+ 
  xlab("Walked Transect Survey: Distribution of Grouped 95th Centiles (m)")+ylab("Receiver")+
  geom_boxplot(alpha=.4)+theme_bw()+
  scale_colour_manual(values=cbbPalette)+scale_fill_manual(values=cbbPalette)+
  geom_vline(xintercept = c(1,2), linetype=3, color="black")+
  annotate(geom="text", x = 0.25, y = 4.5, 
           label="1 m", angle=0,
           colour = "black")+
  annotate(geom="text", x = 2.75, y = 4.5, 
           label="2 m", angle=0,
           colour = "black")+
  annotate(geom="Point", x = 7.47, y = 4, pch=18,cex=4,#BELC
           colour = "#0072B2")+
  annotate(geom="Point", x = 2.15, y = 3, pch=18,cex=4,#BES
           colour = "#000000")+
  annotate(geom="Point", x = 2.94, y = 2, pch=18,cex=4,#iP12
           colour = "#E69F00")+
  annotate(geom="Point", x = 11.68, y = 1, pch=18,cex=4,#iP6
           colour = "#009E73")
T.gg.95
####

R.gr <-rbind(BES_R.gr,BELC_R.gr,iP6_R.gr,iP12_R.gr)
names(F.gr)
#boxplot RD50
R.gg.50 <-ggplot(data=R.gr, 
                 aes(y=factor(Receiver,levels=c("iP6","iP12","BES","BELC")),x=RD50, fill=Receiver,color=Receiver))+
  xlim(0,15)+ 
  xlab("Roaming Point Survey: Distribution of Grouped RD50s (m)")+ylab("Receiver")+
  geom_boxplot(alpha=.4)+theme_bw()+
  scale_colour_manual(values=cbbPalette)+scale_fill_manual(values=cbbPalette)+
  geom_vline(xintercept = c(1,2), linetype=3, color="black")+
  annotate(geom="text", x = 0.25, y = 4.5, 
           label="1 m", angle=0,
           colour = "black")+
  annotate(geom="text", x = 2.75, y = 4.5, 
           label="2 m", angle=0,
           colour = "black")
R.gg.50

#Boxplot RD95
R.gg.95 <-ggplot(data=R.gr, 
                 aes(y=factor(Receiver,levels=c("iP6","iP12","BES","BELC")),x=RD95, fill=Receiver,color=Receiver))+
  xlim(0,20)+
  xlab("Roaming Point Survey: Distribution of Grouped RD95s (m)")+ylab("Receiver")+
  geom_boxplot(alpha=.4)+theme_bw()+
  scale_colour_manual(values=cbbPalette)+scale_fill_manual(values=cbbPalette)+
  geom_vline(xintercept = c(1,2), linetype=3, color="black")+
  annotate(geom="text", x = 0.25, y = 4.5, 
           label="1 m", angle=0,
           colour = "black")+
  annotate(geom="text", x = 2.75, y = 4.5, 
           label="2 m", angle=0,
           colour = "black")+
  annotate(geom="Point", x = 14.78, y = 4.2, pch=18,cex=4,#BELC
           colour = "#0072B2")+
  annotate(geom="Point", x = 6.75, y = 3, pch=18,cex=4,#BES
           colour = "#000000")+
  annotate(geom="Point", x = 6.37, y = 2.2, pch=18,cex=4,#iP12
           colour = "#E69F00")+
  annotate(geom="Point", x = 19.11, y = 1, pch=18,cex=4,#iP6
           colour = "#009E73")
R.gg.95

####

#Composite Figure
ggarrange(F.gg.50,F.gg.95, T.gg.50,T.gg.95, R.gg.50,R.gg.95, 
          ncol=2, nrow=3,widths=c(15,20),common.legend=TRUE,labels="AUTO")

#Graphical Abstract
ggarrange(BES_F.S.gg,F.gg.50,#F.gg.95, 
          ncol=2, nrow=1,widths=c(20,15),labels="AUTO")
